@@ -13,20 +13,20 @@ class AssumptionWarning(Warning):
     pass
 
 
-def raise_assumption_warning(test: bool, msg: str = '') -> None:
-    """ Raises :class:`AssumptionWarning` if :attr:`test` is `True`
+def raise_assumption_warning(test: bool, msg: str = "") -> None:
+    """Raises :class:`AssumptionWarning` if :attr:`test` is `True`
 
     :param test: test that checks for warning
     :param msg: message for more descriptive warning message
     """
 
     if test:
-        message = ('Theory might not be valid anymore!')
+        message = "Theory might not be valid anymore!"
         message += msg
 
         warnings.warn(message, category=AssumptionWarning, stacklevel=5)
         log.info(message)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     pass
