@@ -1,4 +1,4 @@
-from typing import Optional
+from __future__ import annotations
 
 import matplotlib.pyplot as plt
 import numpy as np
@@ -6,16 +6,21 @@ import numpy as np
 from osaft.plotting.base_plotting import BasePlot
 from osaft.plotting.datacontainers.arf_datacontainer import ARFData
 
+NDArray = np.ndarray
+
 
 class ARFPlotter(BasePlot):
-
     def __init__(self) -> None:
         self._abscissa = None
         self._attr_name = None
 
     def plot_solution(
-            self, x_values: np.ndarray, data: ARFData,
-            ax: plt.Axes, plot_method, **kwargs,
+        self,
+        x_values: NDArray,
+        data: ARFData,
+        ax: plt.Axes,
+        plot_method,
+        **kwargs,
     ) -> (plt.Figure, plt.Axes):
         """plot_solution.
 
@@ -28,12 +33,13 @@ class ARFPlotter(BasePlot):
         fig, ax = self._create_figure(ax)
 
         keys = kwargs.keys()
-        if 'ls' not in keys and 'linestyle' not in keys:
-            kwargs['linestyle'] = data.line_style
+        if "ls" not in keys and "linestyle" not in keys:
+            kwargs["linestyle"] = data.line_style
 
         plt.sca(ax)
         plot_method(
-            x_values, data.plotting,
+            x_values,
+            data.plotting,
             label=data.name,
             **kwargs,
         )
@@ -42,7 +48,7 @@ class ARFPlotter(BasePlot):
 
     @staticmethod
     def add_legend(ax: plt.Axes) -> None:
-        """ Adds a legend to the given axis object
+        """Adds a legend to the given axis object
 
         :param ax:
         """
@@ -52,21 +58,21 @@ class ARFPlotter(BasePlot):
     def set_labels(
         ax: plt.Axes,
         attr_name: str,
-        is_normalized: Optional[bool] = False,
+        is_normalized: None | bool = False,
     ) -> None:
-        """ Sets the labels for both plotting axis
+        """Sets the labels for both plotting axis
 
         :param ax: axis to work on
         :param attr_name: name of attribute on abscissa
         :param is_normalized: plotting of normalized solution
         """
-        ax.set_xlabel(f'Attribute {attr_name}')
+        ax.set_xlabel(f"Attribute {attr_name}")
 
         if is_normalized:
-            ax.set_ylabel('normalized ARF [-]')
+            ax.set_ylabel("normalized ARF [-]")
         else:
-            ax.set_ylabel(r'$F^{\mathrm{rad}}$ $\mathrm{[N]}$')
+            ax.set_ylabel(r"$F^{\mathrm{rad}}$ $\mathrm{[N]}$")
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     pass
