@@ -1,16 +1,21 @@
+from __future__ import annotations
+
 from abc import ABC, abstractmethod
-from typing import Optional, Union
 
 import numpy as np
 
-from osaft.core.functions import exp, pi
-from osaft.core.functions import spherical_2_cartesian_coordinates as s2c_coord
+from osaft.core.functions import exp
+from osaft.core.functions import (
+    spherical_2_cartesian_coordinates as s2c_coord,
+)
 from osaft.core.variable import ActiveVariable, PassiveVariable
 from osaft.plotting.datacontainers.base_velocity_datacontainer import (
     VelocityFieldData,
 )
 from osaft.solutions.base_scattering import BaseScattering
 
+NDArray = np.ndarray
+
 
 class ScatteringFieldData(VelocityFieldData, ABC):
     """Container for plotting data for the scattering field
@@ -18,9 +23,9 @@ class ScatteringFieldData(VelocityFieldData, ABC):
     :param sol: solution
     :param r_min: start point for radial plotting range
     :param r_max: end point for tangential plotting range
-    :param theta_min: start point for tangential plotting range
-    :param theta_max: end point for tangential plotting range
     :param res: resolution, if tuple (radial resolution, tangential resolution)
+    :param n_quiver_points: number of points along z-axis for quiver plot
+    :param symmetric: if ``True`` the dataset is assumed to be symmetric
     """
 
     def __init__(
@@ -28,20 +33,25 @@ class ScatteringFieldData(VelocityFieldData, ABC):
         sol: BaseScattering,
         r_min: float,
         r_max: float,
-        theta_min: float = 0,
-        theta_max: float = pi,
-        res: Union[int, tuple[int, int]] = 100,
+        res: int | tuple[int, int] = 100,
+        n_quiver_points: int | tuple[int, int] = 21,
+        symmetric: bool = True,
     ) -> None:
         """Constructor method"""
 
         VelocityFieldData.__init__(
-            self, sol, r_min, r_max, theta_min,
-            theta_max, res,
+            self,
+            sol,
+            r_min,
+            r_max,
+            res,
+            n_quiver_points,
+            symmetric,
         )
 
         # Velocities for the scattering field (complex valued)
-        self._u = ActiveVariable(self._reset_complex_array, 'x coordinate')
-        self._w = ActiveVariable(self._reset_complex_array, 'z coordinate')
+        self._u = ActiveVariable(self._reset_complex_array, "x coordinate")
+        self._w = ActiveVariable(self._reset_complex_array, "z coordinate")
 
         self._u.is_computed_by(self._sol, self._grid, self._mode)
         self._w.is_computed_by(self._sol, self._grid, self._mode)
@@ -51,11 +61,11 @@ class ScatteringFieldData(VelocityFieldData, ABC):
     # -------------------------------------------------------------------------
 
     def get_velocity_magnitude(
-            self,
-            instantaneous: bool = True,
-            phase: float = 0,
-            mode: Optional[int] = None,
-    ) -> tuple[np.ndarray, np.ndarray, np.ndarray]:
+        self,
+        instantaneous: bool = True,
+        phase: float = 0,
+        mode: None | int = None,
+    ) -> tuple[NDArray, NDArray, NDArray]:
         """Returns the velocity magnitudes
 
         returns the coordinates of the points of the plotting grid `x`,
@@ -73,11 +83,11 @@ class ScatteringFieldData(VelocityFieldData, ABC):
             return self.x, self.z, self.u_norm
 
     def get_displacement_magnitude(
-            self,
-            instantaneous: bool = True,
-            phase: float = 0,
-            mode: Optional[int] = None,
-    ) -> tuple[np.ndarray, np.ndarray, np.ndarray]:
+        self,
+        instantaneous: bool = True,
+        phase: float = 0,
+        mode: None | int = None,
+    ) -> tuple[NDArray, NDArray, NDArray]:
         """Returns the displacement magnitudes
 
         returns the coordinates of the points of the plotting grid `x`,
@@ -95,10 +105,10 @@ class ScatteringFieldData(VelocityFieldData, ABC):
             return self.x, self.z, self.u_norm / self.sol.omega
 
     def get_velocity_vector(
-            self,
-            phase: float = 0,
-            mode: Optional[int] = None,
-    ) -> tuple[np.ndarray, np.ndarray, np.ndarray, np.ndarray]:
+        self,
+        phase: float = 0,
+        mode: None | int = None,
+    ) -> tuple[NDArray, NDArray, NDArray, NDArray]:
         """Returns the velocity vectors
 
         returns the coordinates of the points of the plotting grid `x`,
@@ -112,18 +122,15 @@ class ScatteringFieldData(VelocityFieldData, ABC):
         if phase == 0:
             return self.x, self.z, self.u.real, self.w.real
         else:
-            u = self.u * np.exp(- 1j * phase)
-            w = self.w * np.exp(- 1j * phase)
+            u = self.u * np.exp(-1j * phase)
+            w = self.w * np.exp(-1j * phase)
             return self.x, self.w, u.real, w.real
 
     def get_displacement_vector(
-            self,
-            phase: float = 0,
-            mode: Optional[int] = None,
-    ) -> tuple[
-        np.ndarray, np.ndarray,
-        np.ndarray, np.ndarray,
-    ]:
+        self,
+        phase: float = 0,
+        mode: None | int = None,
+    ) -> tuple[NDArray, NDArray, NDArray, NDArray]:
         """Returns the displacement vectors
 
         returns the coordinates of the points of the plotting grid `x`,
@@ -138,8 +145,8 @@ class ScatteringFieldData(VelocityFieldData, ABC):
             u = 1j * self.u / self.sol.omega
             w = 1j * self.w / self.sol.omega
         else:
-            u = self.u * np.exp(- 1j * phase) / self.sol.omega
-            w = self.w * np.exp(- 1j * phase) / self.sol.omega
+            u = self.u * np.exp(-1j * phase) / self.sol.omega
+            w = self.w * np.exp(-1j * phase) / self.sol.omega
         return self.x, self.w, u.real, w.real
 
     # -------------------------------------------------------------------------
@@ -147,9 +154,9 @@ class ScatteringFieldData(VelocityFieldData, ABC):
     # -------------------------------------------------------------------------
 
     def _velocity_norm_inst(
-            self,
-            phase: float,
-    ) -> np.ndarray:
+        self,
+        phase: float,
+    ) -> NDArray:
         """Instantaneous velocity magnitude
 
         :param phase: phase angle
@@ -164,7 +171,7 @@ class ScatteringFieldData(VelocityFieldData, ABC):
     def _disp_norm_inst(
         self,
         phase: float,
-    ) -> np.ndarray:
+    ) -> NDArray:
         """Instantaneous displacement magnitude
 
         :param phase: phase angle
@@ -183,32 +190,104 @@ class ScatteringFieldData(VelocityFieldData, ABC):
         arr_r = self.grid.arr_r
         arr_theta = self.grid.arr_theta
 
-        for index, theta in enumerate(arr_theta):
-
+        for index, r in enumerate(arr_r):
             # Indexing
-            min_index = index * self.resolution
-            max_index = min_index + self.resolution
+            min_index = index * self.grid.res_theta
+            max_index = min_index + self.grid.res_theta
 
             # Coordinates
-            xs, zs = s2c_coord(self.grid.arr_r, theta)
+            xs, zs = s2c_coord(r, arr_theta)
             self._x.value[min_index:max_index] = xs
             self._z.value[min_index:max_index] = zs
 
             # Displacements Velocities
-            u, w = self._compute_velocities(arr_r, theta)
+            u, w = self._compute_velocities(r, arr_theta)
             self._u.value[min_index:max_index] = u
             self._w.value[min_index:max_index] = w
-            self._u_norm.value[min_index:max_index] = np.hypot(
+            self._v_norm.value[min_index:max_index] = np.hypot(
                 np.abs(u),
                 np.abs(w),
             )
 
+    def _compute_data_quiver(self) -> None:
+        """Compute the velocity data for the quiver and store them in
+        respective attributes
+
+        Scattering velocity field is computed on the cartesian grid
+        """
+        arr_r = self.grid_quiver.flat_mesh_r
+        arr_theta = self.grid_quiver.flat_mesh_theta
+        u = np.zeros_like(arr_r, dtype=np.complex_)
+        w = np.zeros_like(arr_r, dtype=np.complex_)
+        for i, (r, theta) in enumerate(zip(arr_r, arr_theta)):
+            u[i], w[i] = self._compute_velocities(r, theta)
+
+        # convert vectors from polar coordinates to cartesian
+        u_cartesian = np.cos(arr_theta) * u - np.sin(arr_theta) * w
+        w_cartesian = np.sin(arr_theta) * u + np.cos(arr_theta) * w
+
+        self._z_quiver.value[:] = self.grid_quiver.flat_mesh_z
+        self._x_quiver.value[:] = self.grid_quiver.flat_mesh_x
+        self._u_quiver.value[:] = u_cartesian
+        self._w_quiver.value[:] = w_cartesian
+
+    def get_velocity_quiver(
+        self,
+        phase: float = 0,
+        mode: None | int = None,
+        scattered: bool = True,
+        incident: bool = True,
+        symmetric: bool = True,
+        animation: bool = True,
+    ) -> tuple[NDArray, NDArray, NDArray, NDArray, float]:
+        """Returns the velocity potential
+
+        returns the coordinates of the points of the plotting grid `x`,
+        `y` and the magnitude of the pressure field at
+        these points
+
+        :param phase: phase angle
+        :param mode: mode of oscillation, if `None` superposition
+        :param scattered: option if scattering field is plotted
+        :param incident: option if incident field is plotted
+        :param symmetric: return symmetric solution
+        :param animation: are the arrows used in an animation
+        """
+        self._mode.value = mode
+        self.scattered = scattered
+        self.incident = incident
+
+        u = self.u_quiver * exp(-1j * phase)
+        w = self.w_quiver * exp(-1j * phase)
+
+        # remove nan from u and w
+        bools = np.isnan(u)
+        u[bools] = 0
+        w[bools] = 0
+
+        if animation:
+            norm = np.max(np.hypot(abs(u), abs(w)))
+        else:
+            norm = np.max(np.hypot(u.real, w.real))
+        scale = self.n_quiver_points / 2 * norm
+
+        z = self.z_quiver
+        x = self.x_quiver
+        if symmetric:
+            z = np.concatenate([z, z])
+            u = np.concatenate([u, u])
+
+            x = np.concatenate([-x, x])
+            w = np.concatenate([-w, w])
+
+        return z, x, u.real, w.real, scale
+
     @abstractmethod
     def _compute_velocities(
         self,
-        arr_r: np.ndarray,
-        theta: float,
-    ) -> tuple[np.ndarray, np.ndarray]:
+        r: float,
+        theta: float | NDArray,
+    ) -> tuple[NDArray, NDArray]:
         """Compute the velocity data and return it
 
         :param arr_r: array of r-coordinates
@@ -216,6 +295,7 @@ class ScatteringFieldData(VelocityFieldData, ABC):
         """
         pass  # pragma: no cover
 
+
 # -----------------------------------------------------------------------------
 # ParticleScatteringData
 # -----------------------------------------------------------------------------
@@ -225,24 +305,26 @@ class ParticleScatteringData(ScatteringFieldData):
     """Container for plotting data for the displacement field in the particle
 
     :param sol: solution
-    :param theta_min: start point for tangential plotting range
-    :param theta_max: end point for tangential plotting range
     :param res: resolution, if tuple (radial resolution, tangential resolution)
+    :param n_quiver_points: anchor points along z for quiver arrows
     """
 
     def __init__(
         self,
         sol: BaseScattering,
-        theta_min: float = 0,
-        theta_max: float = pi,
-        res: Union[int, tuple[int, int]] = 100,
+        res: int | tuple[int, int] = 100,
+        n_quiver_points: int = 21,
     ) -> None:
         """Constructor method"""
 
-        r_min = 1e-30
+        r_min = self._EPS_r_min
         r_max = sol.R_0
         super().__init__(
-            sol, r_min, r_max, theta_min, theta_max, res,
+            sol,
+            r_min,
+            r_max,
+            res,
+            n_quiver_points,
         )
 
     # -------------------------------------------------------------------------
@@ -251,7 +333,7 @@ class ParticleScatteringData(ScatteringFieldData):
 
     def _compute_velocities(
         self,
-        arr_r: np.ndarray,
+        r: NDArray,
         theta: float,
     ):
         """Compute the velocity data and return it
@@ -259,10 +341,11 @@ class ParticleScatteringData(ScatteringFieldData):
         :param arr_r: array of r-coordinates
         :param theta: polar angle
         """
-        u = self.sol.radial_particle_velocity(arr_r, theta, 0, self.mode)
-        w = self.sol.tangential_particle_velocity(arr_r, theta, 0, self.mode)
+        u = self.sol.radial_particle_velocity(r, theta, 0, self.mode)
+        w = self.sol.tangential_particle_velocity(r, theta, 0, self.mode)
         return u, w
 
+
 # -----------------------------------------------------------------------------
 # FluidScatteringData
 # -----------------------------------------------------------------------------
@@ -273,42 +356,46 @@ class FluidScatteringData(ScatteringFieldData):
 
     :param sol: solution
     :param r_max: end point for tangential plotting range
-    :param theta_min: start point for tangential plotting range
-    :param theta_max: end point for tangential plotting range
     :param res: resolution, if tuple (radial resolution, tangential resolution)
+    :param n_quiver_points: anchor points along z for quiver arrows
     """
 
     def __init__(
         self,
         sol: BaseScattering,
         r_max: float,
-        theta_min: float = 0,
-        theta_max: float = pi,
         scattering: bool = True,
         incident: bool = True,
-        res: Union[int, tuple[int, int]] = 100,
+        res: int | tuple[int, int] = 100,
+        n_quiver_points: int = 21,
     ) -> None:
         """Constructor method"""
 
         r_min = sol.R_0
         super().__init__(
-            sol, r_min, r_max, theta_min, theta_max, res,
+            sol,
+            r_min,
+            r_max,
+            res,
+            n_quiver_points,
         )
 
         self._scattered = PassiveVariable(
-            scattering, 'option: plot '
-            'scattering field',
+            scattering,
+            "option: plot scattering field",
         )
         self._incident = PassiveVariable(
-            incident, 'option: plot '
-            'incident field',
+            incident,
+            "option: plot incident field",
         )
 
         self._vel_pot = ActiveVariable(
-            self._reset_complex_array, 'velocity potential',
+            self._reset_complex_array,
+            "velocity potential",
         )
         self._pressure = ActiveVariable(
-            self._reset_complex_array, 'acoustic pressure',
+            self._reset_complex_array,
+            "acoustic pressure",
         )
 
         # Set links
@@ -316,18 +403,19 @@ class FluidScatteringData(ScatteringFieldData):
         self._w.is_computed_by(self._scattered, self._incident)
         self._vel_pot.is_computed_by(self._sol, self._grid, self._mode)
         self._pressure.is_computed_by(self._sol, self._grid, self._mode)
+
     # -------------------------------------------------------------------------
     # API
     # -------------------------------------------------------------------------
 
     def get_pressure(
-            self,
-            instantaneous: bool = True,
-            phase: float = 0,
-            mode: Optional[int] = None,
-            scattered: bool = True,
-            incident: bool = True,
-    ) -> tuple[np.ndarray, np.ndarray, np.ndarray]:
+        self,
+        instantaneous: bool = True,
+        phase: float = 0,
+        mode: None | int = None,
+        scattered: bool = True,
+        incident: bool = True,
+    ) -> tuple[NDArray, NDArray, NDArray]:
         """Returns the velocity potential
 
         returns the coordinates of the points of the plotting grid `x`,
@@ -350,13 +438,13 @@ class FluidScatteringData(ScatteringFieldData):
             return self.x, self.z, np.abs(self.pressure)
 
     def get_velocity_potential(
-            self,
-            instantaneous: bool = True,
-            phase: float = 0,
-            mode: Optional[int] = None,
-            scattered: bool = True,
-            incident: bool = True,
-    ) -> tuple[np.ndarray, np.ndarray, np.ndarray]:
+        self,
+        instantaneous: bool = True,
+        phase: float = 0,
+        mode: None | int = None,
+        scattered: bool = True,
+        incident: bool = True,
+    ) -> tuple[NDArray, NDArray, NDArray]:
         """Returns the velocity potential
 
         returns the coordinates of the points of the plotting grid `x`,
@@ -378,13 +466,13 @@ class FluidScatteringData(ScatteringFieldData):
             return self.x, self.z, np.abs(self.velocity_potential)
 
     def get_velocity_magnitude(
-            self,
-            instantaneous: bool = True,
-            phase: float = 0,
-            mode: Optional[int] = None,
-            scattered: bool = True,
-            incident: bool = True,
-    ) -> tuple[np.ndarray, np.ndarray, np.ndarray]:
+        self,
+        instantaneous: bool = True,
+        phase: float = 0,
+        mode: None | int = None,
+        scattered: bool = True,
+        incident: bool = True,
+    ) -> tuple[NDArray, NDArray, NDArray]:
         """Returns the velocity magnitudes
 
         returns the coordinates of the points of the plotting grid `x`,
@@ -402,15 +490,12 @@ class FluidScatteringData(ScatteringFieldData):
         return super().get_velocity_magnitude(instantaneous, phase, mode)
 
     def get_velocity_vector(
-            self,
-            phase: float = 0,
-            mode: Optional[int] = None,
-            scattered: bool = True,
-            incident: bool = True,
-    ) -> tuple[
-        np.ndarray, np.ndarray,
-        np.ndarray, np.ndarray,
-    ]:
+        self,
+        phase: float = 0,
+        mode: None | int = None,
+        scattered: bool = True,
+        incident: bool = True,
+    ) -> tuple[NDArray, NDArray, NDArray, NDArray]:
         """Returns the velocity vectors
 
         returns the coordinates of the points of the plotting grid `x`,
@@ -427,12 +512,12 @@ class FluidScatteringData(ScatteringFieldData):
         return super().get_velocity_vector(phase, mode)
 
     def get_displacement_vector(
-            self,
-            phase: float = 0,
-            mode: Optional[int] = None,
-            scattered: bool = True,
-            incident: bool = True,
-    ) -> tuple[np.ndarray, np.ndarray, np.ndarray, np.ndarray]:
+        self,
+        phase: float = 0,
+        mode: None | int = None,
+        scattered: bool = True,
+        incident: bool = True,
+    ) -> tuple[NDArray, NDArray, NDArray, NDArray]:
         """Returns the displacement vectors
 
         returns the coordinates of the points of the plotting grid `x`,
@@ -500,20 +585,24 @@ class FluidScatteringData(ScatteringFieldData):
         arr_r = self.grid.arr_r
         arr_theta = self.grid.arr_theta
 
-        for index, theta in enumerate(arr_theta):
-
+        for index, r in enumerate(arr_r):
             # Indexing
-            min_index = index * self.resolution
-            max_index = min_index + self.resolution
+            min_index = index * self.grid.res_theta
+            max_index = min_index + self.grid.res_theta
 
             # Coordinates
-            xs, zs = s2c_coord(self.grid.arr_r, theta)
+            xs, zs = s2c_coord(r, arr_theta)
             self._x.value[min_index:max_index] = xs
             self._z.value[min_index:max_index] = zs
 
-            # Displacements Velocities
+            # Pressure
             pressure = self.sol.pressure(
-                arr_r, theta, 0, self.scattered, self.incident, self.mode,
+                r,
+                arr_theta,
+                0,
+                self.scattered,
+                self.incident,
+                self.mode,
             )
             self._pressure.value[min_index:max_index] = pressure
 
@@ -526,20 +615,24 @@ class FluidScatteringData(ScatteringFieldData):
         arr_r = self.grid.arr_r
         arr_theta = self.grid.arr_theta
 
-        for index, theta in enumerate(arr_theta):
-
+        for index, r in enumerate(arr_r):
             # Indexing
-            min_index = index * self.resolution
-            max_index = min_index + self.resolution
+            min_index = index * self.grid.res_theta
+            max_index = min_index + self.grid.res_theta
 
             # Coordinates
-            xs, zs = s2c_coord(self.grid.arr_r, theta)
+            xs, zs = s2c_coord(r, arr_theta)
             self._x.value[min_index:max_index] = xs
             self._z.value[min_index:max_index] = zs
 
-            # Displacements Velocities
+            # Velocity Potential
             vel_pot = self.sol.velocity_potential(
-                arr_r, theta, 0, self.scattered, self.incident, self.mode,
+                r,
+                arr_theta,
+                0,
+                self.scattered,
+                self.incident,
+                self.mode,
             )
             self._vel_pot.value[min_index:max_index] = vel_pot
 
@@ -548,23 +641,27 @@ class FluidScatteringData(ScatteringFieldData):
     # -------------------------------------------------------------------------
 
     def _compute_velocities(
-            self,
-            arr_r: np.ndarray,
-            theta: float,
-    ) -> tuple[np.ndarray, np.ndarray]:
+        self,
+        r: float,
+        theta: float | NDArray,
+    ) -> tuple[NDArray, NDArray]:
         """Compute the velocity data and return it
 
-        :param arr_r: array of r-coordinates
-        :param theta: polar angle
+        :param r: radial coordinate
+        :param theta: single value or array of tangential coordinates
         """
         u = self.sol.radial_acoustic_fluid_velocity(
-            arr_r, theta, 0,
+            r,
+            theta,
+            0,
             self.scattered,
             self.incident,
             self.mode,
         )
         w = self.sol.tangential_acoustic_fluid_velocity(
-            arr_r, theta, 0,
+            r,
+            theta,
+            0,
             self.scattered,
             self.incident,
             self.mode,
@@ -572,5 +669,5 @@ class FluidScatteringData(ScatteringFieldData):
         return u, w
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     pass
