@@ -1,8 +1,9 @@
-from typing import Optional, Union
+from __future__ import annotations
 
 import matplotlib.pyplot as plt
 import numpy as np
 from matplotlib.animation import FuncAnimation
+from matplotlib.quiver import Quiver
 
 from osaft.core.functions import pi
 from osaft.plotting.datacontainers.scattering_datacontainer import (
@@ -12,37 +13,40 @@ from osaft.plotting.datacontainers.wireframe_datacontainer import (
     ParticleWireframeData,
 )
 from osaft.plotting.scattering.base_plotter import BaseScatteringPlotter
+from osaft.plotting.scattering.base_scattering_plots import (
+    BaseScatteringPlots,
+)
 from osaft.plotting.scattering.tri_plotter import TriangulationPlotter
 from osaft.plotting.scattering.wireframe_plotter import WireframePlotter
 from osaft.solutions.base_scattering import BaseScattering
 
+NDArray = np.ndarray
 
-class ParticleScatteringPlot:
+
+class ParticleScatteringPlot(BaseScatteringPlots):
     """Class for plotting scattering field of the particle
 
     Plots the acoustic field inside the particle using Matplotlib
     tricontourf or tripcolor plotting methods.
 
     :param sol: solution to be plotted
-    :param theta_min: lower limit for tangential plot range
-    :param theta_max: upper limit for tangential plot range
     :param resolution: if tuple (radial resolution, tangential resolution)
+    :param n_quiver_points: anchor points along z for quiver
     :param cmap: color map
     """
 
     def __init__(
-            self,
-            sol: BaseScattering,
-            theta_min: float = 0,
-            theta_max: float = pi,
-            resolution: Union[int, tuple[int, int]] = 100,
-            cmap: str = 'winter',
+        self,
+        sol: BaseScattering,
+        resolution: int | tuple[int, int] = 100,
+        n_quiver_points: int = 21,
+        cmap: str = "winter",
     ):
         """Constructor method"""
         self.data = ParticleScatteringData(
-            sol, theta_min,
-            theta_max,
+            sol,
             resolution,
+            n_quiver_points,
         )
         self.plotter = TriangulationPlotter(True, cmap)
 
@@ -50,16 +54,17 @@ class ParticleScatteringPlot:
     # API
     # -------------------------------------------------------------------------
 
-    def plot(
-            self,
-            inst: bool = True,
-            phase: float = 0,
-            mode: Optional[int] = None,
-            displacement: bool = True,
-            symmetric: bool = True,
-            tripcolor: bool = False,
-            ax: Optional[plt.Axes] = None,
-            **kwargs,
+    def plot_velocity(
+        self,
+        inst: bool = True,
+        phase: float = 0,
+        mode: None | int = None,
+        displacement: bool = False,
+        symmetric: bool = True,
+        quiver_color: None | str = None,
+        tripcolor: bool = False,
+        ax: None | plt.Axes = None,
+        **kwargs,
     ) -> tuple[plt.Figure, plt.Axes]:
         """Tricontourf plot for acoustic velocity field of the particle
 
@@ -70,19 +75,20 @@ class ParticleScatteringPlot:
         or
         `tripcolor
         <https://matplotlib.org/stable/api/_as_gen/matplotlib.pyplot.tripcolor.html>`_
-        if ˜tripcolor = True`
+        if ``tripcolor = True``.
 
-        :param inst: if `True` instantaneous amplitude is plotted
-        :param phase: phase [0, 2 * pi]
+        :param inst: if ``True`` instantaneous amplitude is plotted
+        :param phase: phase :math:`[0, 2\\pi]`
         :param mode: mode of oscillation
-        :param displacement: if `True` displacement, else velocity plot
-        :param symmetric: if `True` the symmetry of the solution is used
+        :param displacement: if ``True`` displacement, else velocity plot
+        :param symmetric: if ``True`` the symmetry of the solution is used
+        :param quiver_color: color of the quiver arrows, if None: no arrows
         :param tripcolor: switches between tripcolor and tricontourf plot
         :param ax: Axes object
         :param kwargs: passed through to tricontourf()
         """
 
-        return self._triangulation_plot(
+        fig, ax = self._triangulation_plot(
             tripcolor=tripcolor,
             inst=inst,
             phase=phase,
@@ -90,19 +96,37 @@ class ParticleScatteringPlot:
             displacement=displacement,
             symmetric=symmetric,
             ax=ax,
-            **kwargs
+            **kwargs,
         )
 
-    def animate(
-            self,
-            frames: int = 64,
-            interval: float = 100.0,
-            mode: Optional[int] = None,
-            displacement: bool = True,
-            symmetric: bool = True,
-            tripcolor: bool = False,
-            ax: Optional[plt.Axes] = None,
-            **kwargs,
+        if quiver_color:
+            # particle plots does not a distinction between scattered and
+            # incident field
+            scattered = incident = False
+            self._overlay_quiver(
+                ax,
+                phase,
+                scattered,
+                incident,
+                mode,
+                symmetric,
+                quiver_color,
+                animation=False,
+            )
+
+        return fig, ax
+
+    def animate_velocity(
+        self,
+        frames: int = 64,
+        interval: float = 100.0,
+        mode: None | int = None,
+        displacement: bool = True,
+        symmetric: bool = True,
+        quiver_color: None | str = None,
+        tripcolor: bool = False,
+        ax: None | plt.Axes = None,
+        **kwargs,
     ) -> FuncAnimation:
         """Tricontourf animation for acoustic velocity field of the particle
 
@@ -113,53 +137,105 @@ class ParticleScatteringPlot:
         or
         `tripcolor
         <https://matplotlib.org/stable/api/_as_gen/matplotlib.pyplot.tripcolor.html>`_
-        if ˜tripcolor = True`
+        if ``tripcolor = True``.
 
 
         :param frames: number of frames for the animation
         :param interval: interval between frames in ms
         :param mode: mode of oscillation
-        :param displacement: if `True` displacement, else velocity plot
-        :param symmetric: if `True` the symmetry of the solution is used
+        :param displacement: if ``True`` displacement, else velocity plot
+        :param symmetric: if ``True`` the symmetry of the solution is used
+        :param quiver_color: color of the quiver arrows, if None: no arrows
         :param tripcolor: switches between tripcolor and tricontourf plot
         :param ax: Axes object
         :param kwargs: passed through to tricontourf()
         """
 
-        return self._triangulation_animation(
-            tripcolor=tripcolor,
-            frames=frames,
-            interval=interval,
-            mode=mode,
-            displacement=displacement,
-            symmetric=symmetric,
-            ax=ax,
-            **kwargs,
-        )
+        if quiver_color:
+
+            fig, ax = self.plot_velocity(
+                inst=False,
+                mode=mode,
+                symmetric=symmetric,
+            )
+
+            # no scattered or incident field for scatterer
+            scattered = incident = False
+            Q = self._overlay_quiver(
+                ax,
+                0,
+                scattered,
+                incident,
+                mode,
+                symmetric,
+                animation=True,
+                quiver_color=quiver_color,
+            )
+            annotation = self.plotter._annotate_phase(ax, 0)
+
+            def animate_quiver(frame: int, frames: int, Q: Quiver, annotation):
+                phase = frame / frames * 2 * pi
+
+                _, _, u, w, _ = self.data.get_velocity_quiver(
+                    phase,
+                    mode,
+                    scattered,
+                    incident,
+                    symmetric,
+                    animation=True,
+                )
+
+                self.plotter._update_phase_annotation(annotation, phase)
+
+                Q.set_UVC(u, w)
+
+                return (Q,)
+
+            anim = FuncAnimation(
+                fig,
+                animate_quiver,
+                frames=frames,
+                interval=interval,
+                blit=False,
+                fargs=(frames, Q, annotation),
+            )
+
+            return anim
+        else:
+            return self._triangulation_animation(
+                tripcolor=tripcolor,
+                frames=frames,
+                interval=interval,
+                mode=mode,
+                displacement=displacement,
+                symmetric=symmetric,
+                ax=ax,
+                **kwargs,
+            )
 
     # -------------------------------------------------------------------------
     # Private Methods
     # -------------------------------------------------------------------------
 
     def _triangulation_plot(
-            self,
-            tripcolor: bool,
-            inst: bool,
-            phase: float,
-            mode: Optional[int],
-            displacement: bool,
-            symmetric: bool,
-            ax: Optional[plt.Axes],
-            **kwargs,
+        self,
+        tripcolor: bool,
+        inst: bool,
+        phase: float,
+        mode: None | int,
+        displacement: bool,
+        symmetric: bool,
+        ax: None | plt.Axes,
+        **kwargs,
     ) -> tuple[plt.Figure, plt.Axes]:
         """Helper function for tripcolor/tricontourf plot
 
-        :param tripcolor: if `True` tripcolor, else tricontourf plot
-        :param inst: if `True` instantaneous amplitude is plotted
-        :param phase: phase [0, 2 * pi]
+        :param tripcolor: if ``True`` tripcolor, else tricontourf plot
+        :param inst: if ``True`` instantaneous amplitude is plotted
+        :param phase: phase :math:`[0, 2\\pi]`
         :param mode: mode of oscillation
-        :param displacement: if `True` displacement, else velocity plot
-        :param symmetric: if `True` the symmetry of the solution is used
+        :param displacement: if ``True`` displacement, else velocity plot
+        :param symmetric: if ``True`` the symmetry of the solution is used
         :param ax: Axes object
         :param kwargs: passed through to plotting method
         """
@@ -167,10 +243,10 @@ class ParticleScatteringPlot:
         # Data
         if displacement:
             X, Z, C = self.data.get_displacement_magnitude(inst, phase, mode)
-            cbar_label = 'Displacement [m]'
+            cbar_label = "Displacement [m]"
         else:
             X, Z, C = self.data.get_velocity_magnitude(inst, phase, mode)
-            cbar_label = 'Velocity [m/s]'
+            cbar_label = "Velocity [m/s]"
         # Replace nan in the center
         C[0] = C[1]
         # Plot
@@ -189,32 +265,30 @@ class ParticleScatteringPlot:
         return fig, ax
 
     def _triangulation_animation(
-            self,
-            tripcolor: bool,
-            frames: int,
-            interval: float,
-            mode: Optional[int],
-            displacement: bool,
-            symmetric: bool,
-            ax: Optional[plt.Axes],
-            **kwargs,
+        self,
+        tripcolor: bool,
+        frames: int,
+        interval: float,
+        mode: None | int,
+        displacement: bool,
+        symmetric: bool,
+        ax: None | plt.Axes,
+        **kwargs,
     ) -> FuncAnimation:
         """Helper function for tripcolor/tricontourf animation
 
-        :param tripcolor: if `True` tripcolor, else tricontourf plot
+        :param tripcolor: if ``True`` tripcolor, else tricontourf plot
         :param frames: number of frames for the animation
         :param interval: interval between frames in ms
         :param mode: mode of oscillation
-        :param displacement: if `True` displacement, else velocity plot
-        :param symmetric: if `True` the symmetry of the solution is used
+        :param displacement: if ``True`` displacement, else velocity plot
+        :param symmetric: if ``True`` the symmetry of the solution is used
         :param ax: Axes object
         :param kwargs: passed through to tricontourf()
         """
+
         # Data function for animation
-        def data_func(phase: float) -> tuple[
-            np.ndarray, np.ndarray,
-            np.ndarray,
-        ]:
+        def data_func(phase: float) -> tuple[NDArray, NDArray, NDArray]:
             """Returns the velocity field for given phase
             Closure is used to fix all additional parameters
             :param phase: phase
@@ -223,11 +297,12 @@ class ParticleScatteringPlot:
                 return self.data.get_displacement_magnitude(True, phase, mode)
             else:
                 return self.data.get_velocity_magnitude(True, phase, mode)
+
         # Color bar label
         if displacement:
-            cbar_label = 'Displacement [m]'
+            cbar_label = "Displacement [m]"
         else:
-            cbar_label = 'Velocity [m/s]'
+            cbar_label = "Velocity [m/s]"
 
         # Get norm
         if displacement:
@@ -246,18 +321,19 @@ class ParticleScatteringPlot:
             C_norm=C,
             radius=self.data.sol.R_0,
             ax=ax,
-            **kwargs
+            **kwargs,
         )
 
-    def plot_evolution(
-            self,
-            inst: bool = True,
-            mode: Optional[int] = None,
-            displacement: bool = False,
-            symmetric: bool = True,
-            tripcolor: bool = False,
-            layout: tuple[int, int] = (3, 3),
-            **kwargs,
+    def plot_velocity_evolution(
+        self,
+        inst: bool = True,
+        mode: None | int = None,
+        displacement: bool = False,
+        symmetric: bool = True,
+        quiver_color: str = None,
+        tripcolor: bool = False,
+        layout: tuple[int, int] = (3, 3),
+        **kwargs,
     ) -> tuple[plt.Figure, plt.Axes]:
         """Tricontourf plot for acoustic velocity field evolution of the
         particle
@@ -270,17 +346,18 @@ class ParticleScatteringPlot:
         or
         `tripcolor
         <https://matplotlib.org/stable/api/_as_gen/matplotlib.pyplot.tripcolor.html>`_
-        if `tripcolor = True`.
+        if ``tripcolor = True``.
 
         The first phase value is always :math:`0\\pi` and the last one
         :math:`2\\pi`. The total number of plots and, hence, also the steps
         between the different phase values is the defined by the product of the
         ``layout`` tuple.
 
-        :param inst: if `True` instantaneous amplitude is plotted
+        :param inst: if ``True`` instantaneous amplitude is plotted
         :param mode: mode of oscillation
-        :param displacement: if `True` displacement, else velocity plot
-        :param symmetric: if `True` the symmetry of the solution is used
+        :param displacement: if ``True`` displacement, else velocity plot
+        :param symmetric: if ``True`` the symmetry of the solution is used
+        :param quiver_color: color of the quiver arrows, if None: no arrows
         :param tripcolor: switches between tripcolor and tricontourf plot
         :param layout: number of rows and columns for plotting
         :param kwargs: passed through to the parent subplots command
@@ -292,22 +369,21 @@ class ParticleScatteringPlot:
         phases = np.linspace(0, 2, num=n)
 
         fig, axes = plt.subplots(
-            n_row, n_col,
-            sharex=True, sharey=True,
+            n_row,
+            n_col,
+            sharex=True,
+            sharey=True,
             **kwargs,
         )
 
         # Data
         if displacement:
-            cbar_label = 'Displacement [m]'
+            cbar_label = "Displacement [m]"
         else:
-            cbar_label = 'Velocity [m/s]'
+            cbar_label = "Velocity [m/s]"
 
         # Data function for subplots
-        def data_func(phase: float) -> tuple[
-            np.ndarray, np.ndarray,
-            np.ndarray,
-        ]:
+        def data_func(phase: float) -> tuple[NDArray, NDArray, NDArray]:
             """Returns the velocity field for given phase
             Closure is used to fix all additional parameters
             :param phase: phase
@@ -350,15 +426,29 @@ class ParticleScatteringPlot:
                 vmin=0,
                 vmax=1.01 * np.nanmax(C_norm),
             )
+            if quiver_color:
+                # particle plots does not a distinction between scattered and
+                # incident field
+                scattered = incident = False
+                self._overlay_quiver(
+                    ax,
+                    phase,
+                    scattered,
+                    incident,
+                    mode,
+                    symmetric,
+                    animation=False,
+                    quiver_color=quiver_color,
+                )
             # remove colorbar
             cbar.remove()
 
-            ax.set_title(f'{phase:.2f}' + r'$\pi$')
+            ax.set_title(f"{phase:.2f}" + r"$\pi$")
 
             if row != (n_row - 1):
-                ax.set_xlabel('')
+                ax.set_xlabel("")
             if col > 0:
-                ax.set_ylabel('')
+                ax.set_ylabel("")
 
         fig.tight_layout()
         cbar = fig.colorbar(cnf, ax=axes.ravel().tolist())
@@ -374,26 +464,29 @@ class ParticleWireframePlot(BaseScatteringPlotter):
     :param nbr_r_levels: number of circles shown in the wireframe
     :param nbr_theta_levels: number of radii shown in the wireframe
     :param resolution: resolution, if tuple `(radial res, tangential res)`
-    :param scale_factor: scaling factor for the displacements, if `None` auto
+    :param scale_factor: scaling factor for the displacements, if ``None`` auto
     """
 
     def __init__(
-            self,
-            sol: BaseScattering,
-            nbr_r_levels: int = 10,
-            nbr_theta_levels: int = 10,
-            resolution: Union[int, tuple[int, int]] = (100, 100),
-            scale_factor: float = 0.1,
+        self,
+        sol: BaseScattering,
+        nbr_r_levels: int = 10,
+        nbr_theta_levels: int = 10,
+        resolution: int | tuple[int, int] = (100, 100),
+        scale_factor: float = 0.1,
     ) -> None:
         # Call to parent class
         super().__init__(True)
 
         self.data = ParticleWireframeData(
-            sol, nbr_r_levels,
-            nbr_theta_levels, resolution,
+            sol,
+            nbr_r_levels,
+            nbr_theta_levels,
+            resolution,
             scale_factor,
         )
         self.plotter = WireframePlotter()
+
     # -------------------------------------------------------------------------
     # API
     # -------------------------------------------------------------------------
@@ -401,14 +494,14 @@ class ParticleWireframePlot(BaseScatteringPlotter):
     def plot(
         self,
         phase: float = 0,
-        mode: Optional[int] = None,
-        ax: Optional[plt.Axes] = None,
+        mode: None | int = None,
+        ax: None | plt.Axes = None,
     ) -> tuple[plt.Figure, plt.Axes]:
         """Plot wireframe
 
         :param phase: phase to be plotted
-        :param mode: mode to be plotted, if `None` superposition of all modes
-        :param ax: if `ax` is passed, plot will be drawn `ax`
+        :param mode: mode to be plotted, if ``None`` superposition of all modes
+        :param ax: if ``ax`` is passed, plot will be drawn on ``ax``
         """
         self.data.mode = mode
         radii, circles = self.data.get_displacements()
@@ -420,15 +513,15 @@ class ParticleWireframePlot(BaseScatteringPlotter):
         self,
         frames: int = 64,
         interval: float = 100.0,
-        mode: Optional[int] = None,
-        ax: Optional[plt.Axes] = None,
+        mode: None | int = None,
+        ax: None | plt.Axes = None,
     ):
         """Animate wireframe
 
         :param frames: number of frames for the animation
         :param interval: interval between frames in milliseconds
-        :param mode: mode to be plotted, if `None` superposition of all modes
-        :param ax: if `ax` is passed, animation will be drawn `ax`
+        :param mode: mode to be plotted, if ``None`` superposition of all modes
+        :param ax: if ``ax`` is passed, plot will be drawn on ``ax``
         """
         self.data.mode = mode
         anim = self.plotter.animate(
@@ -441,23 +534,28 @@ class ParticleWireframePlot(BaseScatteringPlotter):
         return anim
 
     def plot_evolution(
-            self,
-            layout: tuple[int, int] = (3, 3),
-            **kwargs,
+        self,
+        mode: None | int = None,
+        layout: tuple[int, int] = (3, 3),
+        **kwargs,
     ) -> tuple[plt.Figure, plt.Axes]:
         """Plot wireframe over one period
 
         :param layout: subplot layout of the figure
+        :param mode: mode to be plotted, if ``None`` superposition of all modes
         """
 
+        self.data.mode = mode
         n_row, n_col = layout
         n = n_col * n_row
 
         phases = np.linspace(0, 2, num=n)
 
         fig, axes = plt.subplots(
-            n_row, n_col,
-            sharex=True, sharey=True,
+            n_row,
+            n_col,
+            sharex=True,
+            sharey=True,
             **kwargs,
         )
 
@@ -470,16 +568,16 @@ class ParticleWireframePlot(BaseScatteringPlotter):
             radii, circles = self.data.get_displacements()
             _, _ = self.plotter.plot(radii, circles, phase * np.pi, ax)
 
-            ax.set_title(f'{phase:.2f}' + r'$\pi$')
+            ax.set_title(f"{phase:.2f}" + r"$\pi$")
 
             if row != (n_row - 1):
-                ax.set_xlabel('')
+                ax.set_xlabel("")
             if col > 0:
-                ax.set_ylabel('')
+                ax.set_ylabel("")
 
         fig.tight_layout()
         return fig, axes
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     pass
