@@ -2,20 +2,21 @@ from __future__ import annotations
 
 from abc import ABC, abstractmethod
 from collections.abc import Callable, Sequence
-from functools import partial
-from typing import Optional, Union
 
 import numpy as np
 
+from osaft import BackgroundField
 from osaft.core.functions import BesselFunctions as Bf
 from osaft.core.functions import LegendreFunctions as Leg
 from osaft.core.functions import cos, exp, full_range, sin
 from osaft.core.helper import InputHandler
 from osaft.core.variable import PassiveVariable
 
+NDArray = np.ndarray
+
 
 class BaseScattering(ABC):
-    """ Base class for the scattering field that defines the common
+    """Base class for the scattering field that defines the common
     interface.
 
     .. note::
@@ -24,12 +25,19 @@ class BaseScattering(ABC):
     :param N_max: End of the infinite series for the scattering coefficients
     """
 
+    # Required properties by child class
+
+    field: BackgroundField  # Background field instance
+    omega: float  # Angular frequency
+    R_0: float  # Radius
+    rho_f: float  # Fluid density
+    k_f: float  # Fluid wavenumber
+
     def __init__(self, N_max: int = 5) -> None:
-        """Constructor method
-        """
+        """Constructor method"""
 
         # Independent variables
-        self._N_max = PassiveVariable(N_max, 'number of modes N')
+        self._N_max = PassiveVariable(N_max, "number of modes N")
 
     # -------------------------------------------------------------------------
     # API - Acoustic Velocity and Displacement
@@ -37,14 +45,14 @@ class BaseScattering(ABC):
 
     def radial_acoustic_fluid_velocity(
         self,
-        r: Union[float, Sequence],
-        theta: Union[float, Sequence],
-        t: Union[float, Sequence],
+        r: float | Sequence,
+        theta: float | Sequence,
+        t: float | Sequence,
         scattered: bool,
         incident: bool,
-        mode: Optional[int] = None,
-    ) -> Union[complex, np.ndarray]:
-        """ Returns the value for the radial acoustic velocity in [m/s].
+        mode: None | int = None,
+    ) -> complex | NDArray:
+        """Returns the value for the radial acoustic velocity in [m/s].
 
         This method must be implemented by every theory to have a common
         interface for other modules.
@@ -57,6 +65,10 @@ class BaseScattering(ABC):
         :param mode: specific mode number of interest; if `None` then all
                      modes until :attr:`.N_max`
         """
+
+        def radial_func(m: int, s: float) -> complex:
+            return self.V_r(m, s, scattered=scattered, incident=incident)
+
         r, theta, t = InputHandler.handle_input(
             r,
             theta,
@@ -64,11 +76,6 @@ class BaseScattering(ABC):
             self.R_0,
             inside_sphere=False,
         )
-        radial_func = partial(
-            self.V_r,
-            scattered=scattered,
-            incident=incident,
-        )
         out = self.radial_mode_superposition(
             radial_func,
             r,
@@ -81,14 +88,14 @@ class BaseScattering(ABC):
 
     def tangential_acoustic_fluid_velocity(
         self,
-        r: Union[float, Sequence],
-        theta: Union[float, Sequence],
-        t: Union[float, Sequence],
+        r: float | Sequence,
+        theta: float | Sequence,
+        t: float | Sequence,
         scattered: bool,
         incident: bool,
-        mode: Optional[int] = None,
-    ) -> Union[complex, np.ndarray]:
-        """ Returns the value for the tangential acoustic velocity in [m/s].
+        mode: None | int = None,
+    ) -> complex | NDArray:
+        """Returns the value for the tangential acoustic velocity in [m/s].
 
         This method must be implemented by every theory to have a common
         interface for other modules.
@@ -101,6 +108,10 @@ class BaseScattering(ABC):
         :param mode: specific mode number of interest; if `None` then all
                      modes until :attr:`.N_max`
         """
+
+        def radial_func(m: int, s: float) -> complex:
+            return self.V_theta(m, s, scattered=scattered, incident=incident)
+
         r, theta, t = InputHandler.handle_input(
             r,
             theta,
@@ -108,11 +119,7 @@ class BaseScattering(ABC):
             self.R_0,
             inside_sphere=False,
         )
-        radial_func = partial(
-            self.V_theta,
-            scattered=scattered,
-            incident=incident,
-        )
+
         out = self.tangential_mode_superposition(
             radial_func,
             r,
@@ -125,14 +132,14 @@ class BaseScattering(ABC):
 
     def pressure(
         self,
-        r: Union[float, Sequence],
-        theta: Union[float, Sequence],
-        t: Union[float, Sequence],
+        r: float | Sequence,
+        theta: float | Sequence,
+        t: float | Sequence,
         scattered: bool,
         incident: bool,
-        mode: Optional[int] = None,
+        mode: None | int = None,
     ) -> complex:
-        """ Returns the acoustic pressure [Pa].
+        """Returns the acoustic pressure [Pa].
 
         :param r: radial coordinate [m]
         :param theta: tangential coordinate [rad]
@@ -157,7 +164,7 @@ class BaseScattering(ABC):
 
     @abstractmethod
     def potential_coefficient(self, n: int) -> complex:
-        """ Wrapper to the fluid scattering coefficients for an inviscid fluid
+        """Wrapper to the fluid scattering coefficients for an inviscid fluid
 
         This method must be implemented by every theory to have a common
         interface for other modules.
@@ -168,14 +175,14 @@ class BaseScattering(ABC):
 
     def velocity_potential(
         self,
-        r: Union[float, Sequence],
-        theta: Union[float, Sequence],
-        t: Union[float, Sequence],
+        r: float | Sequence,
+        theta: float | Sequence,
+        t: float | Sequence,
         scattered: bool,
         incident: bool,
-        mode: Optional[int] = None,
+        mode: None | int = None,
     ) -> complex:
-        """ Returns the velocity potential of the fluid in [m^2/s].
+        """Returns the velocity potential of the fluid in [m^2/s].
 
         :param r: radial coordinate [m]
         :param theta: tangential coordinate [rad]
@@ -195,40 +202,47 @@ class BaseScattering(ABC):
 
         if not scattered and not incident:
             raise ValueError(
-                'Neither scattered nor incident field has '
-                'been has been selected. Velocity field is zero.', )
+                "Neither scattered nor incident field has "
+                "been has been selected. Velocity field is zero.",
+            )
         elif scattered and incident:
-            def inner_func(n: int, r: float):
-                x = self.k_f * r
-                out = self.field.A_in(n) * Bf.besselj(n, x)
-                out += self.potential_coefficient(n) * Bf.hankelh1(n, x)
-                return out
+
+            def inner_func(m: int, s: float):
+                x = self.k_f * s
+                potential = self.field.A_in(m) * Bf.besselj(m, x)
+                potential += self.potential_coefficient(m) * Bf.hankelh1(m, x)
+                return potential
+
         elif scattered and not incident:
-            def inner_func(n: int, r: float):
-                x = self.k_f * r
-                return self.potential_coefficient(n) * Bf.hankelh1(n, x)
+
+            def inner_func(m: int, s: float):
+                x = self.k_f * s
+                return self.potential_coefficient(m) * Bf.hankelh1(m, x)
+
         else:
-            def inner_func(n: int, r: float):
-                x = self.k_f * r
-                return self.field.A_in(n) * Bf.besselj(n, x)
+
+            def inner_func(m: int, s: float):
+                x = self.k_f * s
+                return self.field.A_in(m) * Bf.besselj(m, x)
 
         if mode is None:
             out = self.radial_mode_superposition(inner_func, r, theta, t, mode)
         else:
-            out = Leg.cos_monomial(mode, theta, inner_func(mode, r))
-            out *= exp(-1j * self.omega * t)
+            out = Leg.cos_monomial(mode, theta, inner_func(mode, r)) * exp(
+                -1j * self.omega * t,
+            )
 
         return out
 
     @abstractmethod
     def radial_particle_velocity(
         self,
-        r: Union[float, Sequence],
-        theta: Union[float, Sequence],
-        t: Union[float, Sequence],
-        mode: Optional[int] = None,
+        r: float | Sequence,
+        theta: float | Sequence,
+        t: float | Sequence,
+        mode: None | int = None,
     ) -> complex:
-        """ Returns the value for the radial particle velocity in [m/s].
+        """Returns the value for the radial particle velocity in [m/s].
 
         This method must be implemented by every theory to have a common
         interface for other modules.
@@ -244,12 +258,12 @@ class BaseScattering(ABC):
     @abstractmethod
     def tangential_particle_velocity(
         self,
-        r: Union[float, Sequence],
-        theta: Union[float, Sequence],
-        t: Union[float, Sequence],
-        mode: Optional[int] = None,
+        r: float | Sequence,
+        theta: float | Sequence,
+        t: float | Sequence,
+        mode: None | int = None,
     ) -> complex:
-        """ Returns the value for the tangential particle velocity in [m/s].
+        """Returns the value for the tangential particle velocity in [m/s].
 
         This method must be implemented by every theory to have a common
         interface for other modules.
@@ -264,11 +278,11 @@ class BaseScattering(ABC):
 
     def radial_particle_displacement(
         self,
-        r: Union[float, Sequence],
-        theta: Union[float, Sequence],
-        t: Union[float, Sequence],
-        mode: Optional[int] = None,
-    ) -> Union[complex, np.ndarray]:
+        r: float | Sequence,
+        theta: float | Sequence,
+        t: float | Sequence,
+        mode: None | int = None,
+    ) -> complex | NDArray:
         """Particle displacement in radial direction
 
         Returns the value of the particle displacement
@@ -285,11 +299,11 @@ class BaseScattering(ABC):
 
     def tangential_particle_displacement(
         self,
-        r: Union[float, Sequence],
-        theta: Union[float, Sequence],
-        t: Union[float, Sequence],
-        mode: Optional[int] = None,
-    ) -> Union[complex, np.ndarray]:
+        r: float | Sequence,
+        theta: float | Sequence,
+        t: float | Sequence,
+        mode: None | int = None,
+    ) -> complex | NDArray:
         """Particle displacement in tangential direction
 
         Returns the value of the particle displacement
@@ -329,11 +343,11 @@ class BaseScattering(ABC):
     def radial_mode_superposition(
         self,
         radial_func: Callable[[int, float], complex],
-        r: Union[float, Sequence],
-        theta: Union[float, Sequence],
-        t: Union[float, Sequence],
+        r: float | Sequence,
+        theta: float | Sequence,
+        t: float | Sequence,
         mode: int = None,
-    ) -> Union[complex, np.ndarray]:
+    ) -> complex | NDArray:
         """Returns either a single mode (``mode=int``) or a the sum until
         :attr:`.N_max` (``mode=None``).
 
@@ -353,7 +367,7 @@ class BaseScattering(ABC):
 
 
         where :math:`f_\\text{n}(r)` is the ``radial_func(n, r)``
-        passsed to the method.
+        passed to the method.
 
         :param radial_func: radial function dependent on :attr:`r`
         :param r: radial coordinate [m]
@@ -378,11 +392,11 @@ class BaseScattering(ABC):
     def tangential_mode_superposition(
         self,
         tangential_func: Callable[[int, float], complex],
-        r: Union[float, Sequence],
-        theta: Union[float, Sequence],
-        t: Union[float, Sequence],
+        r: float | Sequence,
+        theta: float | Sequence,
+        t: float | Sequence,
         mode: int,
-    ) -> Union[complex, np.ndarray]:
+    ) -> complex | NDArray:
         """Returns either a single mode (``mode=int``) or a the sum until
         :attr:`.N_max` (``mode=None``).
 
@@ -402,7 +416,7 @@ class BaseScattering(ABC):
 
 
         where :math:`f_n(r)` is the ``tangential_func(n, r)``
-        passsed to the method.
+        passed to the method.
 
         :param tangential_func: tangential function dependent on :attr:`r`
         :param r: radial coordinate [m]
@@ -435,7 +449,7 @@ class BaseScattering(ABC):
     def V_r_i(
         self,
         n: int,
-        r: Union[float, Sequence],
+        r: float | Sequence,
     ) -> complex:
         """Radial incident field velocity term of mode `n`
         without Legendre coefficients
@@ -445,12 +459,12 @@ class BaseScattering(ABC):
         :param n: mode
         :param r: radial coordinate [m]
         """
-        return self.A_in(n) * self.k_f * Bf.d1_besselj(n, self.k_f * r)
+        return self.field.A_in(n) * self.k_f * Bf.d1_besselj(n, self.k_f * r)
 
     def V_theta_i(
         self,
         n: int,
-        r: Union[float, Sequence],
+        r: float | Sequence,
     ) -> complex:
         """Tangential incident field velocity term of mode n
         without Legendre coefficients
@@ -460,13 +474,13 @@ class BaseScattering(ABC):
         :param n: mode
         :param r: radial coordinate [m]
         """
-        return self.A_in(n) * Bf.besselj(n, self.k_f * r) / r
+        return self.field.A_in(n) * Bf.besselj(n, self.k_f * r) / r
 
     @abstractmethod
     def V_r_sc(
         self,
         n: int,
-        r: Union[float, Sequence],
+        r: float | Sequence,
     ) -> complex:
         """Radial scattering field velocity term of mode `n`
         without Legendre coefficients
@@ -482,7 +496,7 @@ class BaseScattering(ABC):
     def V_theta_sc(
         self,
         n: int,
-        r: Union[float, Sequence],
+        r: float | Sequence,
     ) -> complex:
         """Tangential scattering field velocity term of mode n
         without Legendre coefficients
@@ -519,8 +533,9 @@ class BaseScattering(ABC):
             return self.V_r_i(n, r)
         else:
             raise ValueError(
-                'Neither scattered nor incident field has '
-                'been has been selected. Velocity field is zero.', )
+                "Neither scattered nor incident field has "
+                "been has been selected. Velocity field is zero.",
+            )
 
     def V_theta(
         self,
@@ -549,18 +564,23 @@ class BaseScattering(ABC):
             return self.V_theta_i(n, r)
         else:
             raise ValueError(
-                'Neither scattered nor incident field has '
-                'been has been selected. Velocity field is zero.', )
+                "Neither scattered nor incident field has "
+                "been has been selected. Velocity field is zero.",
+            )
 
 
 class BaseScatteringRigidParticle(ABC):
-    """ Base class for the Scattering Field for a model with a rigid
+    """Base class for the Scattering Field for a model with a rigid
     particle that defines the common interface.
 
     This base class is used for axisymmetric models.
 
     """
 
+    # Required properties by child class
+
+    R_0: float  # Angular frequency
+
     @abstractmethod
     def particle_velocity(self, t: float) -> complex:
         """Particle velocity
@@ -575,11 +595,11 @@ class BaseScatteringRigidParticle(ABC):
 
     def radial_particle_velocity(
         self,
-        r: Union[float, Sequence],
-        theta: Union[float, Sequence],
-        t: Union[float, Sequence],
-        mode: Optional[int] = None,
-    ) -> Union[complex, np.ndarray]:
+        r: float | Sequence,
+        theta: float | Sequence,
+        t: float | Sequence,
+        mode: None | int = None,
+    ) -> complex | NDArray:
         """Particle velocity in radial direction
 
         Returns the value of the particle velocity
@@ -605,11 +625,11 @@ class BaseScatteringRigidParticle(ABC):
 
     def tangential_particle_velocity(
         self,
-        r: Union[float, Sequence],
-        theta: Union[float, Sequence],
-        t: Union[float, Sequence],
-        mode: Optional[int] = None,
-    ) -> Union[complex, np.ndarray]:
+        r: float | Sequence,
+        theta: float | Sequence,
+        t: float | Sequence,
+        mode: None | int = None,
+    ) -> complex | NDArray:
         """Particle velocity in tangential direction
 
         Returns the value of the particle velocity
@@ -635,5 +655,5 @@ class BaseScatteringRigidParticle(ABC):
             return 0 * r * theta * t
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     pass
