@@ -1,7 +1,5 @@
 from __future__ import annotations
 
-from typing import Optional, Union
-
 import numpy as np
 
 from osaft.core.backgroundfields import WaveType
@@ -40,8 +38,9 @@ class ARF(ARFArbitraryRadius):
     """
 
     def __init__(
-        self, f: Union[Frequency, float, int],
-        R_0: Union[Sphere, float, int],
+        self,
+        f: Frequency | float | int,
+        R_0: Sphere | float | int,
         rho_s: float,
         c_s: float,
         eta_s: float,
@@ -52,24 +51,33 @@ class ARF(ARFArbitraryRadius):
         zeta_f: float,
         p_0: float,
         wave_type: WaveType = WaveType.STANDING,
-        position: Optional[float] = None,
+        position: None | float = None,
         small_boundary_layer: bool = False,
         large_boundary_layer: bool = False,
         background_streaming: bool = True,
         N_max: int = 5,
     ) -> None:
-        """Constructor method
-        """
+        """Constructor method"""
 
         # init of parent class
         super().__init__(
-            f=f, R_0=R_0,
-            rho_s=rho_s, c_s=c_s, eta_s=eta_s, zeta_s=zeta_s,
-            rho_f=rho_f, c_f=c_f, eta_f=eta_f, zeta_f=zeta_f,
-            p_0=p_0, wave_type=wave_type, position=position,
+            f=f,
+            R_0=R_0,
+            rho_s=rho_s,
+            c_s=c_s,
+            eta_s=eta_s,
+            zeta_s=zeta_s,
+            rho_f=rho_f,
+            c_f=c_f,
+            eta_f=eta_f,
+            zeta_f=zeta_f,
+            p_0=p_0,
+            wave_type=wave_type,
+            position=position,
             small_boundary_layer=small_boundary_layer,
             large_boundary_layer=large_boundary_layer,
-            N_max=N_max, background_streaming=background_streaming,
+            N_max=N_max,
+            background_streaming=background_streaming,
         )
 
     # -------------------------------------------------------------------------
@@ -93,31 +101,22 @@ class ARF(ARFArbitraryRadius):
         abs_x_v = np.abs(self.x_v)
 
         # Cases
-        if self.small_boundary_layer and (
-            not
-            self.large_boundary_layer
-        ):
+        if self.small_boundary_layer and (not self.large_boundary_layer):
             test = abs_x < EPS and 1 < EPS * abs_x_v
             raise_assumption_warning(test)
             return self._arf_small_particle_small_delta()
-        elif (
-                not self.small_boundary_layer and
-                self.large_boundary_layer
-        ):
+        elif not self.small_boundary_layer and self.large_boundary_layer:
             test = abs_x < EPS * abs_x_v and abs_x_v < EPS
             raise_assumption_warning(test)
             return self._arf_small_particle_large_delta()
-        elif (
-                not self.small_boundary_layer and
-                not self.large_boundary_layer
-        ):
+        elif not self.small_boundary_layer and not self.large_boundary_layer:
             return self._general_solution()
         else:
             raise ValueError(
-                'Small and large viscous boundary layer options cannot'
-                'both be True.',
+                "Small and large viscous boundary layer options cannot"
+                "both be True.",
             )
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     pass
