@@ -1,7 +1,5 @@
 from __future__ import annotations
 
-from typing import Optional, Union
-
 from osaft import log
 from osaft.core.backgroundfields import WaveType
 from osaft.core.frequency import Frequency
@@ -34,51 +32,63 @@ class ARF(ScatteringField, BaseARF):
     """
 
     def __init__(
-        self, f: Union[Frequency, float, int],
-        R_0: Union[Sphere, float, int],
+        self,
+        f: Frequency | float | int,
+        R_0: Sphere | float | int,
         rho_s: float,
-        rho_f: float, c_f: float,
-        p_0: float, wave_type: WaveType, position: Optional[float] = None,
+        rho_f: float,
+        c_f: float,
+        p_0: float,
+        wave_type: WaveType,
+        position: None | float = None,
         N_max: int = 5,
         small_particle_limit: bool = False,
     ) -> None:
-        """Constructor method
-        """
+        """Constructor method"""
 
         # init of parent class
         ScatteringField.__init__(
-            self, f, R_0, rho_s, rho_f, c_f,
-            p_0, wave_type, position, N_max,
+            self,
+            f,
+            R_0,
+            rho_s,
+            rho_f,
+            c_f,
+            p_0,
+            wave_type,
+            position,
+            N_max,
         )
 
         # Passive Variable
         self._small_particle_limit = PassiveVariable(
             small_particle_limit,
-            'small particle limit',
+            "small particle limit",
         )
 
         # Active variables
         self._f_2 = ActiveVariable(
             self._compute_f_2,
-            'dipole scattering coefficient f_2',
+            "dipole scattering coefficient f_2",
         )
         self._Phi = ActiveVariable(
             self._compute_Phi,
-            'acoustic contrast factor Phi',
+            "acoustic contrast factor Phi",
         )
 
         self._f_2.is_computed_by(self.scatterer._rho_s, self.fluid._rho_f)
         self._Phi.is_computed_by(
-            self._f_2, self.field._wave_type,
+            self._f_2,
+            self.field._wave_type,
             self._rho_tilde,
         )
 
-        self._FFGG = ActiveListVariable(self._compute_FFGG, 'FFGG(n)')
-        self._FGFG = ActiveListVariable(self._compute_FGFG, 'FGFG(n)')
-        self._HH = ActiveListVariable(self._compute_HH, 'HH(n)')
+        self._FFGG = ActiveListVariable(self._compute_FFGG, "FFGG(n)")
+        self._FGFG = ActiveListVariable(self._compute_FGFG, "FGFG(n)")
+        self._HH = ActiveListVariable(self._compute_HH, "HH(n)")
 
         self._FFGG.is_computed_by(self._alpha, self._rho_tilde)
-        self._FGFG .is_computed_by(self._alpha, self._rho_tilde)
+        self._FGFG.is_computed_by(self._alpha, self._rho_tilde)
         self._HH.is_computed_by(self._alpha, self._rho_tilde, self._FFGG)
 
         log.info(str(self))
@@ -86,58 +96,76 @@ class ARF(ScatteringField, BaseARF):
 
     def __repr__(self):
         return (
-            f'{type(self)}(f={self.f}, R_0={self.R_0}, '
-            f'rho_s={self.rho_s}, rho_f={self.rho_f}, c_f={self.c_f}, '
-            f'p_0={self.p_0}, position={self.position}, '
-            f'small_particle_limit={self.small_particle_limit}, '
-            f'wave_type={self.wave_type}, N_max={self.N_max})'
+            f"{type(self)}(f={self.f}, R_0={self.R_0}, "
+            f"rho_s={self.rho_s}, rho_f={self.rho_f}, c_f={self.c_f}, "
+            f"p_0={self.p_0}, position={self.position}, "
+            f"small_particle_limit={self.small_particle_limit}, "
+            f"wave_type={self.wave_type}, N_max={self.N_max})"
         )
 
     def __str__(self):
-        out = 'King\'s solution to the ARF with following properties: \n'
+        out = "King's solution to the ARF with following properties: \n"
         out += SF.get_str_text(
-            'Small Particle Limit', '',
-            self.small_particle_limit, '',
+            "Small Particle Limit",
+            "",
+            self.small_particle_limit,
+            "",
         )
-        out += SF.get_str_text('Wave type', '', self.wave_type, '')
-        out += SF.get_str_text('Frequency', 'f', self.f, 'Hz')
-        out += SF.get_str_text('Pressure', 'p_0', self.p_0, 'Pa')
+        out += SF.get_str_text("Wave type", "", self.wave_type, "")
+        out += SF.get_str_text("Frequency", "f", self.f, "Hz")
+        out += SF.get_str_text("Pressure", "p_0", self.p_0, "Pa")
         out += SF.get_str_text(
-            'Position', 'd',
-            self.position, 'rad',
+            "Position",
+            "d",
+            self.position,
+            "rad",
         )
         out += SF.get_str_text(
-            'Wavelength', 'lambda',
-            self.field.lambda_f, 'm',
+            "Wavelength",
+            "lambda",
+            self.field.lambda_f,
+            "m",
         )
 
-        out += 'Fluid\n'
+        out += "Fluid\n"
         out += SF.get_str_text(
-            'Density', 'rho_f',
-            self.rho_f, 'kg/m^3',
+            "Density",
+            "rho_f",
+            self.rho_f,
+            "kg/m^3",
         )
         out += SF.get_str_text(
-            'Sound Speed', 'c_0',
-            self.c_f, 'm/s',
+            "Sound Speed",
+            "c_0",
+            self.c_f,
+            "m/s",
         )
         out += SF.get_str_text(
-            'Compressibility', 'kappa_f',
-            self.kappa_f, '1/Pa',
+            "Compressibility",
+            "kappa_f",
+            self.kappa_f,
+            "1/Pa",
         )
 
-        out += 'Particle\n'
+        out += "Particle\n"
         out += SF.get_str_text(
-            'Radius', 'R_0',
-            self.R_0, 'm',
+            "Radius",
+            "R_0",
+            self.R_0,
+            "m",
         )
         out += SF.get_str_text(
-            'Density', 'rho_s',
-            self.rho_s, 'kg/m^3',
+            "Density",
+            "rho_s",
+            self.rho_s,
+            "kg/m^3",
         )
-        out += 'Other\n'
+        out += "Other\n"
         out += SF.get_str_text(
-            '#modes', 'N_max',
-            self.N_max, None,
+            "#modes",
+            "N_max",
+            self.N_max,
+            None,
         )
         return out
 
@@ -164,19 +192,17 @@ class ARF(ScatteringField, BaseARF):
     # -------------------------------------------------------------------------
     @property
     def f_2(self) -> float:
-        """Dipole scatting coefficient :math:`f_2` [-]
-        """
+        """Dipole scatting coefficient :math:`f_2` [-]"""
         return self._f_2.value
 
     @property
     def Phi(self) -> float:
-        r"""Acoustic contrast factor :math:`\Phi` [-]
-        """
+        r"""Acoustic contrast factor :math:`\Phi` [-]"""
         return self._Phi.value
 
     @property
     def small_particle_limit(self) -> bool:
-        """ ARF for the small particle limit
+        """ARF for the small particle limit
 
         :getter: returns if small particle limit is computed
         :setter: automatically invokes
@@ -199,7 +225,7 @@ class ARF(ScatteringField, BaseARF):
         if self.wave_type == WaveType.STANDING:
             return 1 / 3 + self.f_2 / 2
         else:
-            out = (1 + 2 / 9 * (1 - 1 / self.rho_tilde) ** 2)
+            out = 1 + 2 / 9 * (1 - 1 / self.rho_tilde) ** 2
             out /= (2 + 1 / self.rho_tilde) ** 2
             return out
 
@@ -212,13 +238,13 @@ class ARF(ScatteringField, BaseARF):
         """
         first = 1 / self.HH(0)
         second = 2 / self.HH(1)
-        second *= (self.alpha ** 2 - 3 * (1 - 1 / self.rho_tilde)) ** 2
-        second /= self.alpha ** 8
+        second *= (self.alpha**2 - 3 * (1 - 1 / self.rho_tilde)) ** 2
+        second /= self.alpha**8
 
         def higher():
             def term(order):
                 out = (order + 1) / self.HH(order)
-                out *= (self.alpha ** 2 - order * (order + 2)) ** 2
+                out *= (self.alpha**2 - order * (order + 2)) ** 2
                 out /= self.alpha ** (4 * order + 4)
                 return out
 
@@ -229,8 +255,8 @@ class ARF(ScatteringField, BaseARF):
             return term_out
 
         out = 2 * pi * self.rho_f * self.field.abs_A_squared
-        out *= (first + second + higher())
-        out /= self.alpha ** 2
+        out *= first + second + higher()
+        out /= self.alpha**2
 
         return out
 
@@ -242,15 +268,15 @@ class ARF(ScatteringField, BaseARF):
         Radiation Pressure on Spheres"
         """
         first = self.FFGG(0) / (self.alpha * self.HH(0))
-        second = - 2 / self.alpha ** 5 * self.FFGG(1) / self.HH(1)
-        second *= self.alpha ** 2 - 3 * (1 - 1 / self.rho_tilde)
+        second = -2 / self.alpha**5 * self.FFGG(1) / self.HH(1)
+        second *= self.alpha**2 - 3 * (1 - 1 / self.rho_tilde)
 
         def higher():
             def term(order):
-                out = (- 1) ** order * (order + 1)
+                out = (-1) ** order * (order + 1)
                 out /= self.alpha ** (2 * order + 3)
                 out *= self.FFGG(order) / self.HH(order)
-                out *= self.alpha ** 2 - order * (order + 2)
+                out *= self.alpha**2 - order * (order + 2)
                 return out
 
             term_out = 0.0
@@ -261,7 +287,7 @@ class ARF(ScatteringField, BaseARF):
 
         out = pi * self.rho_f * self.field.abs_A_squared
         out *= sin(2 * self.position)
-        out *= (first + second + higher())
+        out *= first + second + higher()
 
         return out
 
@@ -324,16 +350,16 @@ class ARF(ScatteringField, BaseARF):
 
     def _compute_HH(self, n: int) -> complex:
         if n == 1:
-            out = (self.alpha ** 2 - 3 * (1 - 1 / self.rho_tilde)) ** 2
-            out /= self.alpha ** 10
+            out = (self.alpha**2 - 3 * (1 - 1 / self.rho_tilde)) ** 2
+            out /= self.alpha**10
             out += self.FFGG(n) ** 2
             return out
         else:
-            out = (self.alpha ** 2 - n * (n + 2)) ** 2
+            out = (self.alpha**2 - n * (n + 2)) ** 2
             out /= self.alpha ** (4 * n + 6)
             out += self.FFGG(n) ** 2
             return out
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     pass
