@@ -1,7 +1,5 @@
 from __future__ import annotations
 
-from typing import Optional, Union
-
 from osaft import log
 from osaft.core.backgroundfields import BackgroundField, WaveType
 from osaft.core.basecomposite import BaseSphereFrequencyComposite
@@ -49,19 +47,23 @@ class ARF(BaseARF, BaseSphereFrequencyComposite, BaseSolution):
     supported_wavetypes = [WaveType.STANDING, WaveType.TRAVELLING]
 
     def __init__(
-        self, f: Union[Frequency, float, int],
-        R_0: Union[Sphere, float, int],
-        rho_s: float, c_s: float,
-        rho_f: float, c_f: float, eta_f: float,
-        p_0: float, wave_type: WaveType,
-        position: Optional[float] = None,
+        self,
+        f: Frequency | float | int,
+        R_0: Sphere | float | int,
+        rho_s: float,
+        c_s: float,
+        rho_f: float,
+        c_f: float,
+        eta_f: float,
+        p_0: float,
+        wave_type: WaveType,
+        position: None | float = None,
     ) -> None:
-        """Constructor method
-        """
+        """Constructor method"""
         # init of parent class
         # init of parent class
         BaseSphereFrequencyComposite.__init__(self, f, R_0)
-        BaseSolution.__init__(self, 'Settnes2012')
+        BaseSolution.__init__(self, "Settnes2012")
 
         # Initialize Components
         self.scatterer = InviscidFluid(self.frequency, rho_s, c_s)
@@ -71,32 +73,31 @@ class ARF(BaseARF, BaseSphereFrequencyComposite, BaseSolution):
         # Dependent variables
         self._f_1 = ActiveVariable(
             self._compute_f_1,
-            'monopole scattering coefficient f_1',
+            "monopole scattering coefficient f_1",
         )
         self._f_2 = ActiveVariable(
             self._compute_f_2,
-            'dipole scattering coefficient f_2',
+            "dipole scattering coefficient f_2",
         )
         self._gamma = ActiveVariable(
             self._compute_gamma,
-            'dimensionless variable gamma',
+            "dimensionless variable gamma",
         )
         self._delta_t = ActiveVariable(
             self._compute_delta_t,
-            'dimensionless boundary layer '
-            'thickness',
+            "dimensionless boundary layer " "thickness",
         )
         self._kappa_t = ActiveVariable(
             self._compute_kappa_t,
-            'compressibility ratio kappa tilde',
+            "compressibility ratio kappa tilde",
         )
         self._rho_t = ActiveVariable(
             self._compute_rho_t,
-            'density ratio rho tilde',
+            "density ratio rho tilde",
         )
         self._Phi = ActiveVariable(
             self._compute_Phi,
-            'acoustic contrast factor Phi',
+            "acoustic contrast factor Phi",
         )
 
         # Dependencies
@@ -141,72 +142,97 @@ class ARF(BaseARF, BaseSphereFrequencyComposite, BaseSolution):
             return self._traveling_wave_solution()
 
     def _standing_wave_solution(self) -> float:
-        out = 4 * pi * self.E_ac * self.R_0 ** 3 * self.k_f.real
+        out = 4 * pi * self.E_ac * self.R_0**3 * self.k_f.real
         out *= self.Phi * sin(2 * self.position)
         return out
 
     def _traveling_wave_solution(self) -> float:
         # This expression has been corrected according to Marston (2013).
-        return 2 * pi * self.R_0**3 * self.k_f.real * self.f_2.imag * self.E_ac
+        return (
+            2 * pi * self.R_0**3 * self.k_f.real * self.f_2.imag * self.E_ac
+        )
 
     def __repr__(self):
         return (
-            f'SettnesARF({self.f}, {self.R_0}, {self.rho_s}, '
-            f'{self.c_s}, {self.rho_f}, {self.c_f}, {self.eta_f}'
-            f'{self.wave_type}, {self.p_0}, {self.position}'
+            f"SettnesARF({self.f}, {self.R_0}, {self.rho_s}, "
+            f"{self.c_s}, {self.rho_f}, {self.c_f}, {self.eta_f}"
+            f"{self.wave_type}, {self.p_0}, {self.position}"
         )
 
     def __str__(self):
         out = "Settnes' & Bruus' solution with following properties: \n"
-        out += SF.get_str_text('Frequency', 'f', self.f, 'Hz')
-        out += SF.get_str_text('Pressure', 'p_0', self.p_0, 'Pa')
+        out += SF.get_str_text("Frequency", "f", self.f, "Hz")
+        out += SF.get_str_text("Pressure", "p_0", self.p_0, "Pa")
         out += SF.get_str_text(
-            'Position', 'd',
-            self.position, 'rad',
+            "Position",
+            "d",
+            self.position,
+            "rad",
         )
         out += SF.get_str_text(
-            'Wave Type', '',
-            self.wave_type, None,
+            "Wave Type",
+            "",
+            self.wave_type,
+            None,
         )
         out += SF.get_str_text(
-            'Wavelength', 'lambda',
-            self.field.lambda_f, 'm',
+            "Wavelength",
+            "lambda",
+            self.field.lambda_f,
+            "m",
         )
 
-        out += 'Fluid\n'
+        out += "Fluid\n"
         out += SF.get_str_text(
-            'Density', 'rho_f',
-            self.rho_f, 'kg/m^3',
+            "Density",
+            "rho_f",
+            self.rho_f,
+            "kg/m^3",
         )
         out += SF.get_str_text(
-            'Sound Speed', 'c_0',
-            self.c_f, 'm/s',
+            "Sound Speed",
+            "c_0",
+            self.c_f,
+            "m/s",
         )
         out += SF.get_str_text(
-            'Viscosity', 'eta_f',
-            self.eta_f, 'Pa s',
+            "Viscosity",
+            "eta_f",
+            self.eta_f,
+            "Pa s",
         )
         out += SF.get_str_text(
-            'Compressibility', 'kappa_f',
-            self.kappa_f, '1/Pa',
+            "Compressibility",
+            "kappa_f",
+            self.kappa_f,
+            "1/Pa",
         )
 
-        out += 'Particle\n'
+        out += "Particle\n"
         out += SF.get_str_text(
-            'Radius', 'R_0',
-            self.R_0, 'm',
+            "Radius",
+            "R_0",
+            self.R_0,
+            "m",
         )
         out += SF.get_str_text(
-            'Density', 'rho_s',
-            self.rho_s, 'kg/m^3',
+            "Density",
+            "rho_s",
+            self.rho_s,
+            "kg/m^3",
         )
         out += SF.get_str_text(
-            'Speed of Sound', 'c_s',
-            self.scatterer.c_f, 'm/s',
+            "Speed of Sound",
+            "c_s",
+            self.scatterer.c_f,
+            "m/s",
         )
         out += SF.get_str_text(
-            'Compressibility', 'kappa_s',
-            self.kappa_s, '1/Pa', False,
+            "Compressibility",
+            "kappa_s",
+            self.kappa_s,
+            "1/Pa",
+            False,
         )
         return out
 
@@ -265,8 +291,7 @@ class ARF(BaseARF, BaseSphereFrequencyComposite, BaseSolution):
 
     @property
     def Phi(self) -> float:
-        """Acoustic contrast factor :math:`\\Phi` [-]
-        """
+        """Acoustic contrast factor :math:`\\Phi` [-]"""
         return self._Phi.value
 
     # -------------------------------------------------------------------------
@@ -297,7 +322,7 @@ class ARF(BaseARF, BaseSphereFrequencyComposite, BaseSolution):
 
     @property
     def wave_type(self) -> WaveType:
-        """ Wraps to
+        """Wraps to
         :attr:`osaft.core.backgroundfields.BackgroundField.wave_type`
         """
         return self.field.wave_type
@@ -323,8 +348,7 @@ class ARF(BaseARF, BaseSphereFrequencyComposite, BaseSolution):
 
     @property
     def rho_s(self) -> float:
-        """ Wraps to :attr:`osaft.core.fluids.InviscidFluid.rho_s`
-        """
+        """Wraps to :attr:`osaft.core.fluids.InviscidFluid.rho_s`"""
         return self.scatterer.rho_f
 
     @rho_s.setter
@@ -333,8 +357,7 @@ class ARF(BaseARF, BaseSphereFrequencyComposite, BaseSolution):
 
     @property
     def c_s(self) -> float:
-        """ Wraps to :attr:`osaft.core.fluids.InviscidFluid.c_s`
-        """
+        """Wraps to :attr:`osaft.core.fluids.InviscidFluid.c_s`"""
         return self.scatterer.c_f
 
     @c_s.setter
@@ -347,8 +370,7 @@ class ARF(BaseARF, BaseSphereFrequencyComposite, BaseSolution):
 
     @property
     def kappa_s(self) -> float:
-        """ Wraps to :attr:`osaft.core.fluids.InviscidFluid.kappa_f`
-        """
+        """Wraps to :attr:`osaft.core.fluids.InviscidFluid.kappa_f`"""
         return self.scatterer.kappa_f
 
     # -------------------------------------------------------------------------
@@ -357,8 +379,7 @@ class ARF(BaseARF, BaseSphereFrequencyComposite, BaseSolution):
 
     @property
     def rho_f(self) -> float:
-        """ Wraps to :attr:`osaft.core.fluids.ViscousFluid.rho_f`
-        """
+        """Wraps to :attr:`osaft.core.fluids.ViscousFluid.rho_f`"""
         return self.fluid.rho_f
 
     @rho_f.setter
@@ -367,8 +388,7 @@ class ARF(BaseARF, BaseSphereFrequencyComposite, BaseSolution):
 
     @property
     def c_f(self) -> float:
-        """ Wraps to :attr:`osaft.core.fluids.ViscousFluid.c_f`
-        """
+        """Wraps to :attr:`osaft.core.fluids.ViscousFluid.c_f`"""
         return self.fluid.c_f
 
     @c_f.setter
@@ -377,8 +397,7 @@ class ARF(BaseARF, BaseSphereFrequencyComposite, BaseSolution):
 
     @property
     def eta_f(self) -> float:
-        """ Wraps to :attr:`osaft.core.fluids.ViscousFluid.eta_f`
-        """
+        """Wraps to :attr:`osaft.core.fluids.ViscousFluid.eta_f`"""
         return self.fluid.eta_f
 
     @eta_f.setter
@@ -391,20 +410,17 @@ class ARF(BaseARF, BaseSphereFrequencyComposite, BaseSolution):
 
     @property
     def kappa_f(self) -> float:
-        """ Wraps to :attr:`osaft.core.fluids.ViscousFluid.kappa_f`
-        """
+        """Wraps to :attr:`osaft.core.fluids.ViscousFluid.kappa_f`"""
         return self.fluid.kappa_f
 
     @property
     def k_f(self) -> complex:
-        """ Wraps to :attr:`osaft.core.fluids.ViscousFluid.k_f`
-        """
+        """Wraps to :attr:`osaft.core.fluids.ViscousFluid.k_f`"""
         return self.fluid.k_f
 
     @property
     def delta(self):
-        """ Wraps to :attr:`osaft.core.fluids.ViscousFluid.k_f`
-        """
+        """Wraps to :attr:`osaft.core.fluids.ViscousFluid.k_f`"""
         return self.fluid.delta
 
     # -------------------------------------------------------------------------
@@ -416,7 +432,9 @@ class ARF(BaseARF, BaseSphereFrequencyComposite, BaseSolution):
 
     def _compute_f_2(self) -> complex:
         return (
-            2 * (1 - self.gamma) * (self.rho_t - 1)
+            2
+            * (1 - self.gamma)
+            * (self.rho_t - 1)
             / (2 * self.rho_t + 1 - 3 * self.gamma)
         )
 
@@ -436,5 +454,5 @@ class ARF(BaseARF, BaseSphereFrequencyComposite, BaseSolution):
         return 1 / 3 * self.f_1 + 1 / 2 * self.f_2.real
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     pass
