@@ -1,7 +1,5 @@
 from __future__ import annotations
 
-from typing import Optional, Union
-
 from osaft import log
 from osaft.core.backgroundfields import WaveType, WrongWaveTypeError
 from osaft.core.frequency import Frequency
@@ -34,15 +32,21 @@ class ARF(ScatteringField, BaseARF):
     """
 
     def __init__(
-        self, f: Union[Frequency, float, int],
-        R_0: Union[Sphere, float, int],
-        rho_s: float, c_s: float, rho_f: float, c_f: float,
-        p_0: float, wave_type: WaveType,
-        position: Optional[float] = None, N_max: int = 5,
-        small_particle: bool = False, bubble_solution: bool = False,
+        self,
+        f: Frequency | float | int,
+        R_0: Sphere | float | int,
+        rho_s: float,
+        c_s: float,
+        rho_f: float,
+        c_f: float,
+        p_0: float,
+        wave_type: WaveType,
+        position: None | float = None,
+        N_max: int = 5,
+        small_particle: bool = False,
+        bubble_solution: bool = False,
     ) -> None:
-        """Constructor method
-        """
+        """Constructor method"""
 
         # init of parent class
         ScatteringField.__init__(
@@ -61,24 +65,24 @@ class ARF(ScatteringField, BaseARF):
 
         self._small_particle = PassiveVariable(
             small_particle,
-            'Small Particle Limit',
+            "Small Particle Limit",
         )
         self._bubble_solution = PassiveVariable(
             bubble_solution,
-            'Bubble solution Limit',
+            "Bubble solution Limit",
         )
 
         self._F = ActiveVariable(
             self._compute_F,
-            'density-compressibility factor',
+            "density-compressibility factor",
         )
         self._K_n = ActiveListVariable(
             self._compute_K_n,
-            'Coefficient K_n',
+            "Coefficient K_n",
         )
         self._M_n = ActiveListVariable(
             self._compute_M_n,
-            'Coefficient M_n',
+            "Coefficient M_n",
         )
 
         self._F.is_computed_by(
@@ -108,69 +112,92 @@ class ARF(ScatteringField, BaseARF):
 
     def __repr__(self):
         return (
-            f'{type(self)}(f={self.f}, R_0={self.R_0}, '
-            f'rho_s={self.rho_s}, rho_f={self.rho_f}, '
-            f'c_f={self.c_f}, c_s={self.c_s}'
-            f'p_0={self.p_0}, position={self.position}, '
-            f'wave_type={self.wave_type}, N_max={self.N_max}'
-            f'small_particle={self.small_particle}, '
-            f'bubble_solution={self.bubble_solution})'
+            f"{type(self)}(f={self.f}, R_0={self.R_0}, "
+            f"rho_s={self.rho_s}, rho_f={self.rho_f}, "
+            f"c_f={self.c_f}, c_s={self.c_s}"
+            f"p_0={self.p_0}, position={self.position}, "
+            f"wave_type={self.wave_type}, N_max={self.N_max}"
+            f"small_particle={self.small_particle}, "
+            f"bubble_solution={self.bubble_solution})"
         )
 
     def __str__(self):
-        out = 'Yosioka\'s solution to the ARF field'
-        out += ' with following properties: \n'
-        out += SF.get_str_text('Wave type', '', self.wave_type, '')
-        out += SF.get_str_text('Frequency', 'f', self.f, 'Hz')
-        out += SF.get_str_text('Pressure', 'p_0', self.p_0, 'Pa')
+        out = "Yosioka's solution to the ARF field"
+        out += " with following properties: \n"
+        out += SF.get_str_text("Wave type", "", self.wave_type, "")
+        out += SF.get_str_text("Frequency", "f", self.f, "Hz")
+        out += SF.get_str_text("Pressure", "p_0", self.p_0, "Pa")
         out += SF.get_str_text(
-            'Position', 'd', self.position, 'rad',
+            "Position",
+            "d",
+            self.position,
+            "rad",
         )
         out += SF.get_str_text(
-            'Wavelength', 'lambda',
-            self.field.lambda_f, 'm',
+            "Wavelength",
+            "lambda",
+            self.field.lambda_f,
+            "m",
         )
 
-        out += 'Fluid\n'
+        out += "Fluid\n"
         out += SF.get_str_text(
-            'Density', 'rho_f',
-            self.rho_f, 'kg/m^3',
+            "Density",
+            "rho_f",
+            self.rho_f,
+            "kg/m^3",
         )
         out += SF.get_str_text(
-            'Sound Speed', 'c_f',
-            self.c_f, 'm/s',
+            "Sound Speed",
+            "c_f",
+            self.c_f,
+            "m/s",
         )
         out += SF.get_str_text(
-            'Compressibility', 'kappa_f',
-            self.kappa_f, '1/Pa',
+            "Compressibility",
+            "kappa_f",
+            self.kappa_f,
+            "1/Pa",
         )
 
-        out += 'Particle\n'
+        out += "Particle\n"
         out += SF.get_str_text(
-            'Radius', 'R_0',
-            self.R_0, 'm',
+            "Radius",
+            "R_0",
+            self.R_0,
+            "m",
         )
         out += SF.get_str_text(
-            'Density', 'rho_s',
-            self.rho_s, 'kg/m^3',
+            "Density",
+            "rho_s",
+            self.rho_s,
+            "kg/m^3",
         )
         out += SF.get_str_text(
-            'Speed of sound', 'c_s',
-            self.c_s, 'm/s',
+            "Speed of sound",
+            "c_s",
+            self.c_s,
+            "m/s",
         )
-        out += 'Limiting cases\n'
+        out += "Limiting cases\n"
         out += SF.get_str_text(
-            'Small Particle', 'small_particle',
-            self.small_particle, None,
+            "Small Particle",
+            "small_particle",
+            self.small_particle,
+            None,
         )
         out += SF.get_str_text(
-            'Bubble', 'bubble_solution',
-            self.bubble_solution, None,
+            "Bubble",
+            "bubble_solution",
+            self.bubble_solution,
+            None,
         )
-        out += 'Other\n'
+        out += "Other\n"
         out += SF.get_str_text(
-            '#modes', 'N_max',
-            self.N_max, None,
+            "#modes",
+            "N_max",
+            self.N_max,
+            None,
         )
         return out
 
@@ -206,8 +233,8 @@ class ARF(ScatteringField, BaseARF):
             return self._bubble_arf()
         elif not self.small_particle and self.bubble_solution:
             raise ValueError(
-                'The bubble solution is only defined for small '
-                'bubbles. Set small_particle to True.',
+                "The bubble solution is only defined for small "
+                "bubbles. Set small_particle to True.",
             )
         elif self.small_particle:
             return self._small_particle_arf()
@@ -287,11 +314,11 @@ class ARF(ScatteringField, BaseARF):
             s5 *= n + 1
             out[4] += s5
 
-        out[0] *= -self.R_0 ** 2
-        out[1] *= self.lambda_rho ** 2
+        out[0] *= -self.R_0**2
+        out[1] *= self.lambda_rho**2
         out[2] *= -self.R_0 * self.lambda_rho
         out[3] *= self.R_0 * self.lambda_rho
-        out[4] *= - (self.k_f ** 2 * self.R_0 ** 2 * self.lambda_rho ** 2)
+        out[4] *= -(self.k_f**2 * self.R_0**2 * self.lambda_rho**2)
 
         # (Eq. 44)
         out = 2 * pi * self.rho_f * sum(out)
@@ -313,8 +340,8 @@ class ARF(ScatteringField, BaseARF):
         ]
         for c in conditions:
             if c:
-                text = 'Criteria for small particle might not be fulfilled.'
-                text += 'Consider using another model approach'
+                text = "Criteria for small particle might not be fulfilled."
+                text += "Consider using another model approach"
                 log.warning(text)
                 break
         if self.wave_type == WaveType.STANDING:
@@ -329,8 +356,12 @@ class ARF(ScatteringField, BaseARF):
         """
 
         out = (
-            pi * self.R_0 ** 2 * 4 * (self.k_f * self.R_0) ** 4
-            * self.I_ac / self.c_f
+            pi
+            * self.R_0**2
+            * 4
+            * (self.k_f * self.R_0) ** 4
+            * self.I_ac
+            / self.c_f
             * self.F
         )
         return out
@@ -341,7 +372,11 @@ class ARF(ScatteringField, BaseARF):
         """
 
         out = (
-            pi * self.R_0 ** 2 * 4 * self.k_f * self.R_0
+            pi
+            * self.R_0**2
+            * 4
+            * self.k_f
+            * self.R_0
             * self.E_ac
             * sin(2 * self.position)
             * self.F
@@ -362,8 +397,8 @@ class ARF(ScatteringField, BaseARF):
         ]
         for c in conditions:
             if c:
-                text = 'Criteria for small bubbles might not be fulfilled.'
-                text += 'Consider using another model approach'
+                text = "Criteria for small bubbles might not be fulfilled."
+                text += "Consider using another model approach"
                 log.info(text)
                 break
 
@@ -378,17 +413,10 @@ class ARF(ScatteringField, BaseARF):
         Eq. (68)
         :rtype: float
         """
-        out = (
-            4 * pi * self.R_0 ** 2
-            * (self.k_s * self.R_0) ** 4
-            * self.I_ac
-        )
-        out /= (
-            self.c_f
-            * (
-                self.sigma ** 2 * (self.k_s * self.R_0) ** 6
-                + (3 * self.lambda_rho - (self.k_s * self.R_0) ** 2) ** 2
-            )
+        out = 4 * pi * self.R_0**2 * (self.k_s * self.R_0) ** 4 * self.I_ac
+        out /= self.c_f * (
+            self.sigma**2 * (self.k_s * self.R_0) ** 6
+            + (3 * self.lambda_rho - (self.k_s * self.R_0) ** 2) ** 2
         )
         return out
 
@@ -396,7 +424,7 @@ class ARF(ScatteringField, BaseARF):
         """
         Eq. (74)
         """
-        out = -4 * pi / self.k_f ** 2
+        out = -4 * pi / self.k_f**2
         out *= self.E_ac
         out *= sin(2 * self.position)
         out *= self.F
@@ -431,20 +459,19 @@ class ARF(ScatteringField, BaseARF):
                 return self._compute_F_standing()
 
         elif (
-                self.wave_type == WaveType.TRAVELLING
-                and not self.bubble_solution
+            self.wave_type == WaveType.TRAVELLING and not self.bubble_solution
         ):
             return self._compute_F_travelling()
         else:
             raise WrongWaveTypeError(
-                'Factor F is only defined for particles travelling and '
-                'standing waves and for bubbles in standing waves',
+                "Factor F is only defined for particles travelling and "
+                "standing waves and for bubbles in standing waves",
             )
 
     def _compute_F_travelling(self):
         # Eq. 60
-        out = (- (1 + 2 * self.lambda_rho))
-        out /= (3 * self.lambda_rho * self.sigma ** 2)
+        out = -(1 + 2 * self.lambda_rho)
+        out /= 3 * self.lambda_rho * self.sigma**2
         out += self.lambda_rho
         out *= out
         out += (2 / 9) * ((1 - self.lambda_rho) ** 2)
@@ -455,14 +482,14 @@ class ARF(ScatteringField, BaseARF):
         # Eq. 63
         out = self.lambda_rho + (2 * (self.lambda_rho - 1) / 3)
         out /= 1 + 2 * self.lambda_rho
-        out -= 1 / (3 * self.lambda_rho * self.sigma ** 2)
+        out -= 1 / (3 * self.lambda_rho * self.sigma**2)
         return out
 
     def _compute_F_standing_bubble(self):
         # Eq. 75 (corrected)
-        resonance_term = (3 * self.lambda_rho - self.x_s ** 2)
-        out = self.sigma * self.x_s ** 3 * resonance_term  # Wrong in paper
-        out /= (self.sigma ** 2 * self.x_s ** 6 + resonance_term ** 2)
+        resonance_term = 3 * self.lambda_rho - self.x_s**2
+        out = self.sigma * self.x_s**3 * resonance_term  # Wrong in paper
+        out /= self.sigma**2 * self.x_s**6 + resonance_term**2
         return out
 
     def K_n(self, n: int) -> complex:
@@ -504,5 +531,5 @@ class ARF(ScatteringField, BaseARF):
         return out
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     pass
