@@ -1,7 +1,5 @@
 from __future__ import annotations
 
-from typing import Optional, Union
-
 from osaft.core.backgroundfields import BackgroundField, WaveType
 from osaft.core.basecomposite import BaseSphereFrequencyComposite
 from osaft.core.fluids import InviscidFluid
@@ -29,19 +27,22 @@ class BaseYosioka(BaseSphereFrequencyComposite, BaseSolution):
     supported_wavetypes = [WaveType.STANDING, WaveType.TRAVELLING]
 
     def __init__(
-        self, f: Union[Frequency, float, int],
-        R_0: Union[Sphere, float, int],
-        rho_s: float, c_s: float,
-        rho_f: float, c_f: float,
-        p_0: float, wave_type: WaveType,
-        position: Optional[float] = None,
+        self,
+        f: Frequency | float | int,
+        R_0: Sphere | float | int,
+        rho_s: float,
+        c_s: float,
+        rho_f: float,
+        c_f: float,
+        p_0: float,
+        wave_type: WaveType,
+        position: None | float = None,
     ) -> None:
 
-        """Constructor method
-        """
+        """Constructor method"""
         # init of parent class
         BaseSphereFrequencyComposite.__init__(self, f, R_0)
-        BaseSolution.__init__(self, 'Yosioka1955')
+        BaseSolution.__init__(self, "Yosioka1955")
 
         # Initialize Components
         self.scatterer = InviscidFluid(self.frequency, rho_s, c_s)
@@ -51,20 +52,20 @@ class BaseYosioka(BaseSphereFrequencyComposite, BaseSolution):
         # Dependent variables
         self._lambda_rho = ActiveVariable(
             self._compute_lambda_rho,
-            'ratio of densities',
+            "ratio of densities",
         )
         self._sigma = ActiveVariable(
             self._compute_sigma,
-            'ratio of speed of sounds',
+            "ratio of speed of sounds",
         )
 
         self._x_f = ActiveVariable(
             self._compute_x_f,
-            'dimensionless fluid wavenumber',
+            "dimensionless fluid wavenumber",
         )
         self._x_s = ActiveVariable(
             self._compute_x_s,
-            'dimensionless particle wavenumber',
+            "dimensionless particle wavenumber",
         )
 
         # Dependencies
@@ -82,26 +83,22 @@ class BaseYosioka(BaseSphereFrequencyComposite, BaseSolution):
 
     @property
     def sigma(self) -> float:
-        """ratio of speeds of sound [-].
-         """
+        """ratio of speeds of sound [-]."""
         return self._sigma.value
 
     @property
     def lambda_rho(self) -> float:
-        """ratio of densities [-]
-         """
+        """ratio of densities [-]"""
         return self._lambda_rho.value
 
     @property
     def x_f(self) -> float:
-        """ dimensionless wavenumber in the fluid [-]
-        """
+        """dimensionless wavenumber in the fluid [-]"""
         return self._x_f.value
 
     @property
     def x_s(self) -> float:
-        """ dimensionless wavenumber in the particle
-        """
+        """dimensionless wavenumber in the particle"""
         return self._x_s.value
 
     # -------------------------------------------------------------------------
@@ -121,8 +118,7 @@ class BaseYosioka(BaseSphereFrequencyComposite, BaseSolution):
 
     @property
     def p_0(self) -> float:
-        """Wraps to :attr:`osaft.core.backgroundfields.BackgroundField.p_0`
-        """
+        """Wraps to :attr:`osaft.core.backgroundfields.BackgroundField.p_0`"""
         return self.field.p_0
 
     @p_0.setter
@@ -131,7 +127,7 @@ class BaseYosioka(BaseSphereFrequencyComposite, BaseSolution):
 
     @property
     def wave_type(self) -> WaveType:
-        """ Wraps to
+        """Wraps to
         :attr:`osaft.core.backgroundfields.BackgroundField.wave_type`
         """
         return self.field.wave_type
@@ -146,8 +142,7 @@ class BaseYosioka(BaseSphereFrequencyComposite, BaseSolution):
 
     @property
     def rho_s(self) -> float:
-        """Wraps to :attr:`osaft.core.fluids.InviscidFluid.rho_f`
-        """
+        """Wraps to :attr:`osaft.core.fluids.InviscidFluid.rho_f`"""
         return self.scatterer.rho_f
 
     @rho_s.setter
@@ -156,8 +151,7 @@ class BaseYosioka(BaseSphereFrequencyComposite, BaseSolution):
 
     @property
     def c_s(self) -> float:
-        """Wraps to :attr:`osaft.core.fluids.InviscidFluid.c_f`
-        """
+        """Wraps to :attr:`osaft.core.fluids.InviscidFluid.c_f`"""
         return self.scatterer.c_f
 
     @c_s.setter
@@ -170,8 +164,7 @@ class BaseYosioka(BaseSphereFrequencyComposite, BaseSolution):
 
     @property
     def rho_f(self) -> float:
-        """Wraps to :attr:`osaft.core.fluids.InviscidFluid.rho_f`
-        """
+        """Wraps to :attr:`osaft.core.fluids.InviscidFluid.rho_f`"""
         return self.fluid.rho_f
 
     @rho_f.setter
@@ -180,8 +173,7 @@ class BaseYosioka(BaseSphereFrequencyComposite, BaseSolution):
 
     @property
     def c_f(self) -> float:
-        """Wraps to :attr:`osaft.core.fluids.InviscidFluid.c_f`
-        """
+        """Wraps to :attr:`osaft.core.fluids.InviscidFluid.c_f`"""
         return self.fluid.c_f
 
     @c_f.setter
@@ -194,14 +186,12 @@ class BaseYosioka(BaseSphereFrequencyComposite, BaseSolution):
 
     @property
     def kappa_f(self) -> float:
-        """Wraps to :attr:`osaft.core.fluids.InviscidFluid.kappa_f`
-        """
+        """Wraps to :attr:`osaft.core.fluids.InviscidFluid.kappa_f`"""
         return self.fluid.kappa_f
 
     @property
     def k_f(self) -> float:
-        """Wraps to :attr:`osaft.core.fluids.InviscidFluid.k_f`
-        """
+        """Wraps to :attr:`osaft.core.fluids.InviscidFluid.k_f`"""
         return self.fluid.k_f
 
     # -------------------------------------------------------------------------
@@ -210,8 +200,7 @@ class BaseYosioka(BaseSphereFrequencyComposite, BaseSolution):
 
     @property
     def k_s(self) -> float:
-        """Wraps to :attr:`osaft.core.fluids.InviscidFluid.k_f`
-        """
+        """Wraps to :attr:`osaft.core.fluids.InviscidFluid.k_f`"""
         return self.scatterer.k_f
 
     # -------------------------------------------------------------------------
@@ -243,25 +232,21 @@ class BaseYosioka(BaseSphereFrequencyComposite, BaseSolution):
     # -------------------------------------------------------------------------
 
     def _compute_sigma(self) -> float:
-        """Compute sigma (ratio of speed of sound)
-        """
+        """Compute sigma (ratio of speed of sound)"""
         return self.c_s / self.c_f
 
     def _compute_lambda_rho(self) -> float:
-        """Compute lambda (ratio of densities)
-        """
+        """Compute lambda (ratio of densities)"""
         return self.rho_s / self.rho_f
 
     def _compute_x_f(self) -> float:
-        """Compute x_f
-        """
+        """Compute x_f"""
         return self.R_0 * self.k_f
 
     def _compute_x_s(self) -> float:
-        """Compute x_s
-        """
+        """Compute x_s"""
         return self.R_0 * self.k_s
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     pass
