@@ -9,10 +9,10 @@ from osaft import ViscoelasticFluid, ViscousFluid, WaveType
 from osaft.core.functions import BesselFunctions as Bf
 from osaft.core.functions import LegendreFunctions as Leg
 from osaft.core.functions import exp, full_range, pi
+from osaft.tests.testing_parameters import RandomParameters
 
 
 class BaseHelperScattering:
-
     @staticmethod
     def get_random_n():
         return randint(0, 10)
@@ -32,6 +32,8 @@ class BaseHelperScattering:
 
 class HelperScattering(BaseHelperScattering):
 
+    parameters: RandomParameters
+
     # -------------------------------------------------------------------------
     # Thresholds
     # -------------------------------------------------------------------------
@@ -76,20 +78,24 @@ class HelperScattering(BaseHelperScattering):
 
     def radial_acoustic_fluid_velocity(
         self,
-        r, theta,
+        r,
+        theta,
         t,
         scattered,
         incident,
         mode=None,
     ) -> float:
         if scattered and incident:
+
             def v(l, x):
                 return self.V_r_sc(l, x) + self.V_r_i(l, x)
+
         elif scattered and not incident:
             v = self.V_r_sc
         elif not scattered and incident:
             v = self.V_r_i
         else:
+
             def v(l, x):
                 return 0
 
@@ -98,26 +104,33 @@ class HelperScattering(BaseHelperScattering):
             out *= Leg.cos_monomial(mode, theta, v(mode, r))
         else:
             out *= Leg.cos_poly(
-                theta, [
-                    v(n, r)
-                    for n in full_range(self.cls.N_max)
-                ],
+                theta,
+                [v(n, r) for n in full_range(self.cls.N_max)],
             )
         return out
 
     def tangential_acoustic_fluid_velocity(
-        self, r, theta, t, scattered, incident, mode=None,
+        self,
+        r,
+        theta,
+        t,
+        scattered,
+        incident,
+        mode=None,
     ) -> float:
         if scattered and incident:
+
             def v(l, x):
                 if l == 0:
                     return 0
                 return self.V_theta_sc(l, x) + self.V_theta_i(l, x)
+
         elif scattered and not incident:
             v = self.V_theta_sc
         elif not scattered and incident:
             v = self.V_theta_i
         else:
+
             def v(l, x):
                 return 0
 
@@ -127,20 +140,17 @@ class HelperScattering(BaseHelperScattering):
         else:
             out *= Leg.first_cos_poly(
                 theta,
-                [
-                    v(n, r) for n in
-                    full_range(0, self.cls.N_max)
-                ],
+                [v(n, r) for n in full_range(0, self.cls.N_max)],
             )
         return out
 
     def radial_particle_displacement(self, r, theta, t, mode):
         velocity = self.radial_particle_velocity(r, theta, t, mode)
-        return velocity / (- 1j * self.cls.omega)
+        return velocity / (-1j * self.cls.omega)
 
     def tangential_particle_displacement(self, r, theta, t, mode):
         velocity = self.tangential_particle_velocity(r, theta, t, mode)
-        return velocity / (- 1j * self.cls.omega)
+        return velocity / (-1j * self.cls.omega)
 
     @abstractmethod
     def radial_particle_velocity(self, r, theta, t, mode) -> float:
@@ -156,7 +166,7 @@ class HelperScattering(BaseHelperScattering):
 
     def test_radial_particle_velocity(self) -> None:
         # skip changing R_0 so the RT.is_inside_sphere does not get triggered
-        self.test_variables.remove(self._R_0)
+        self.parameters.list_parameters.remove(self.parameters._R_0)
         for n in range(self.n_runs):
             n = self.get_random_n()
             r = self.cls.R_0 * 0.9
@@ -172,7 +182,7 @@ class HelperScattering(BaseHelperScattering):
 
     def test_tangential_particle_velocity(self) -> None:
         # skip changing R_0 so the RT.is_inside_sphere does not get triggered
-        self.test_variables.remove(self._R_0)
+        self.parameters.list_parameters.remove(self.parameters._R_0)
         for _ in range(self.n_runs):
             n = self.get_random_n()
             r = self.cls.R_0 * 0.9
@@ -188,7 +198,7 @@ class HelperScattering(BaseHelperScattering):
 
     def test_radial_particle_displacement(self) -> None:
         # skip changing R_0 so the RT.is_inside_sphere does not get triggered
-        self.test_variables.remove(self._R_0)
+        self.parameters.list_parameters.remove(self.parameters._R_0)
         for n in range(self.n_runs):
             n = self.get_random_n()
             r = self.cls.R_0 * 0.9
@@ -204,7 +214,7 @@ class HelperScattering(BaseHelperScattering):
 
     def test_tangential_particle_displacement(self) -> None:
         # skip changing R_0 so the RT.is_inside_sphere does not get triggered
-        self.test_variables.remove(self._R_0)
+        self.parameters.list_parameters.remove(self.parameters._R_0)
         for _ in range(self.n_runs):
             n = self.get_random_n()
             r = self.cls.R_0 * 0.9
@@ -222,16 +232,24 @@ class HelperScattering(BaseHelperScattering):
         # neither scattering nor incident is selected
         with self.assertRaises(ValueError):
             self.cls.radial_acoustic_fluid_velocity(
-                self.cls.R_0, 0, 0, False, False,
+                self.cls.R_0,
+                0,
+                0,
+                False,
+                False,
             )
         with self.assertRaises(ValueError):
             self.cls.tangential_acoustic_fluid_velocity(
-                self.cls.R_0, 0, 0, False, False,
+                self.cls.R_0,
+                0,
+                0,
+                False,
+                False,
             )
 
     def test_radial_acoustic_fluid_velocity(self) -> None:
         # skip changing R_0 so the RT.is_outside_sphere does not get triggered
-        self.test_variables.remove(self._R_0)
+        self.parameters.list_parameters.remove(self.parameters._R_0)
         for incident, scattering in [
             (True, True),
             (True, False),
@@ -261,7 +279,7 @@ class HelperScattering(BaseHelperScattering):
 
     def test_tangential_acoustic_fluid_velocity(self) -> None:
         # skip changing R_0 so the RT.is_outside_sphere does not get triggered
-        self.test_variables.remove(self._R_0)
+        self.parameters.list_parameters.remove(self.parameters._R_0)
         for incident, scattering in [
             (True, True),
             (True, False),
@@ -300,23 +318,35 @@ class HelperScattering(BaseHelperScattering):
         self.assertRaises(
             ValueError,
             self.cls.radial_particle_velocity,
-            0, lst, 0,
+            0,
+            lst,
+            0,
         )
         self.assertRaises(
             ValueError,
             self.cls.tangential_particle_velocity,
-            0, lst, 0,
+            0,
+            lst,
+            0,
         )
 
         self.assertRaises(
             ValueError,
             self.cls.radial_acoustic_fluid_velocity,
-            0, lst, 0, True, True,
+            0,
+            lst,
+            0,
+            True,
+            True,
         )
         self.assertRaises(
             ValueError,
             self.cls.tangential_acoustic_fluid_velocity,
-            0, lst, 0, True, True,
+            0,
+            lst,
+            0,
+            True,
+            True,
         )
 
     def test_RadiusTester_present(self):
@@ -325,12 +355,18 @@ class HelperScattering(BaseHelperScattering):
         lst[-1] = 1.1 * self.R_0
 
         self.assertRaises(
-            ValueError, self.cls.radial_particle_velocity,
-            lst, 0, 0,
+            ValueError,
+            self.cls.radial_particle_velocity,
+            lst,
+            0,
+            0,
         )
         self.assertRaises(
-            ValueError, self.cls.tangential_particle_velocity,
-            lst, 0, 0,
+            ValueError,
+            self.cls.tangential_particle_velocity,
+            lst,
+            0,
+            0,
         )
 
         lst = 1.01 * self.R_0 * (np.random.rand(10) + 1)
@@ -340,12 +376,20 @@ class HelperScattering(BaseHelperScattering):
         self.assertRaises(
             ValueError,
             self.cls.radial_acoustic_fluid_velocity,
-            lst, 0, 0, True, True,
+            lst,
+            0,
+            0,
+            True,
+            True,
         )
         self.assertRaises(
             ValueError,
             self.cls.tangential_acoustic_fluid_velocity,
-            lst, 0, 0, True, True,
+            lst,
+            0,
+            0,
+            True,
+            True,
         )
 
     # -------------------------------------------------------------------------
@@ -354,9 +398,9 @@ class HelperScattering(BaseHelperScattering):
 
     def test_boundary_conditions(self) -> None:
         test_tangential = False
-        if (
-            isinstance(self.cls.fluid, ViscousFluid)
-            or isinstance(self.cls.fluid, ViscoelasticFluid)
+        if isinstance(self.cls.fluid, ViscousFluid) or isinstance(
+            self.cls.fluid,
+            ViscoelasticFluid,
         ):
             test_tangential = True
 
@@ -368,18 +412,28 @@ class HelperScattering(BaseHelperScattering):
             t = self.get_random_t()
             for mode in modes_to_test:
                 with self.subTest(
-                        msg='Testing radial condition',
-                        theta=f'\u03C0 * {theta}', t=t,
-                        mode=mode,
+                    msg="Testing radial condition",
+                    theta=f"\u03C0 * {theta}",
+                    t=t,
+                    mode=mode,
                 ):
                     v_s = self.cls.radial_acoustic_fluid_velocity(
-                        self.R_0, pi * theta, t, True, True, mode=mode,
+                        self.R_0,
+                        pi * theta,
+                        t,
+                        True,
+                        True,
+                        mode=mode,
                     )
                     v_p = self.cls.radial_particle_velocity(
-                        self.R_0, pi * theta, t, mode=mode,
+                        self.R_0,
+                        pi * theta,
+                        t,
+                        mode=mode,
                     )
                     self.assertAlmostEqual(
-                        v_p, v_s,
+                        v_p,
+                        v_s,
                         threshold=self.v_boundary_conditions,
                     )
 
@@ -389,18 +443,26 @@ class HelperScattering(BaseHelperScattering):
                 t = self.get_random_t()
                 for mode in modes_to_test:
                     with self.subTest(
-                            msg='Testing tangential condition',
-                            theta=f'\u03C0 * {theta}', t=t,
-                            mode=mode,
+                        msg="Testing tangential condition",
+                        theta=f"\u03C0 * {theta}",
+                        t=t,
+                        mode=mode,
                     ):
                         v_s = self.cls.tangential_acoustic_fluid_velocity(
-                            self.R_0, pi * theta, t, True, True,
+                            self.R_0,
+                            pi * theta,
+                            t,
+                            True,
+                            True,
                         )
                         v_p = self.cls.tangential_particle_velocity(
-                            self.R_0, pi * theta, t,
+                            self.R_0,
+                            pi * theta,
+                            t,
                         )
                         self.assertAlmostEqual(
-                            v_p, v_s,
+                            v_p,
+                            v_s,
                             threshold=self.v_boundary_conditions,
                         )
 
@@ -441,38 +503,39 @@ class HelperCompareScattering(BaseHelperScattering):
                         v2 = func_2(r, theta, t, True, True)
 
                     subtest_msg = (
-                        f'{msg}, '
-                        f'theta={theta/np.pi:1.2f}*\u03C0, '
-                        f'r={r/self.R_0:1.2f}*R_0 , '
-                        f't={t:1.2e}'
+                        f"{msg}, "
+                        f"theta={theta/np.pi:1.2f}*\u03C0, "
+                        f"r={r/self.R_0:1.2f}*R_0 , "
+                        f"t={t:1.2e}"
                     )
 
                     with self.subTest(msg=subtest_msg):
                         self.assertAlmostEqual(
-                            v1, v2,
+                            v1,
+                            v2,
                             threshold=self.scattering_compare_threshold,
                         )
 
-    @unittest.skip('unstable test')
+    @unittest.skip("unstable test")
     def test_sc_comparison_outside(self) -> None:
-        msg = 'Tangential fluid velocity'
+        msg = "Tangential fluid velocity"
         func_1 = self.cls.tangential_acoustic_fluid_velocity
         func_2 = self.compare_cls.tangential_acoustic_fluid_velocity
         self._sc_comparison(func_1, func_2, msg, inside_sphere=False)
 
-        msg = 'Radial fluid velocity'
+        msg = "Radial fluid velocity"
         func_1 = self.cls.radial_acoustic_fluid_velocity
         func_2 = self.compare_cls.radial_acoustic_fluid_velocity
         self._sc_comparison(func_1, func_2, msg, inside_sphere=False)
 
-    @unittest.skip('unstable test')
+    @unittest.skip("unstable test")
     def test_sc_comparison_inside(self) -> None:
-        msg = 'Tangential particle velocity'
+        msg = "Tangential particle velocity"
         func_1 = self.cls.tangential_particle_velocity
         func_2 = self.compare_cls.tangential_particle_velocity
         self._sc_comparison(func_1, func_2, msg, inside_sphere=True)
 
-        msg = 'Radial particle velocity'
+        msg = "Radial particle velocity"
         func_1 = self.cls.radial_particle_velocity
         func_2 = self.compare_cls.radial_particle_velocity
         self._sc_comparison(func_1, func_2, msg, inside_sphere=True)
