@@ -3,11 +3,10 @@ import unittest
 from osaft.core.frequency import Frequency
 from osaft.core.functions import sqrt
 from osaft.core.solids import ElasticSolid, RigidSolid
-from osaft.tests.basetest import BaseTest
+from osaft.tests.basetest_numeric import BaseTestSolutions
 
 
 class TestConversion(unittest.TestCase):
-
     def setUp(self) -> None:
         self.rho = 8960
         self.c_1 = 4521.3
@@ -68,8 +67,7 @@ class TestConversion(unittest.TestCase):
         self.assertAlmostEqual(self.G, G_test, delta=1)
 
 
-class TestRigidSolid(BaseTest):
-
+class TestRigidSolid(BaseTestSolutions):
     def setUp(self) -> None:
 
         super().setUp()
@@ -99,8 +97,7 @@ class TestRigidSolid(BaseTest):
         )
 
 
-class TestElasticSolid(BaseTest):
-
+class TestElasticSolid(BaseTestSolutions):
     def setUp(self) -> None:
 
         super().setUp()
@@ -108,10 +105,13 @@ class TestElasticSolid(BaseTest):
         self.frequency = Frequency(self.f)
         self.cls = ElasticSolid(self.f, self.E_s, self.nu_s, self.rho_s)
         self.composite_cls = ElasticSolid(
-            self.frequency, self.E_s, self.nu_s,
+            self.frequency,
+            self.E_s,
+            self.nu_s,
             self.rho_s,
         )
         self.list_cls = [self.cls, self.composite_cls]
+
     # -------------------------------------------------------------------------
     # Methods
     # -------------------------------------------------------------------------
@@ -130,7 +130,8 @@ class TestElasticSolid(BaseTest):
 
     def compute_c_l(self) -> float:
         return sqrt(
-            self.E_s * (1 - self.nu_s)
+            self.E_s
+            * (1 - self.nu_s)
             / (self.rho_s * (1 + self.nu_s) * (1 - 2 * self.nu_s)),
         )
 
@@ -236,5 +237,5 @@ class TestElasticSolid(BaseTest):
             self.cls.nu_s = 0.6
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
