@@ -4,55 +4,24 @@ import unittest
 import numpy as np
 from matplotlib import pyplot as plt
 
-from osaft import ARFPlot, WaveType, gorkov1962, king1934, yosioka1955
+from osaft import ARFPlot
 from osaft.solutions.base_arf import BaseARF
-from osaft.tests.basetest_plotting import BaseTestPlotting
+from osaft.tests.plotting.basetest_plotting import BaseTestPlotting
+from osaft.tests.solution_factory import SolutionFactory
 
 
 def create_solutions() -> list[BaseARF]:
-    f = 1e6
-    R_0 = 1e-6
-    rho_s = 1850
-    c_s = 5000
-    rho_f = 997
-    c_f = 1500
-    p_0 = 1e5
-    wave_types = WaveType.TRAVELLING
-    position = None
 
-    out = []
-    out.append(
-        king1934.ARF(
-            f, R_0,
-            rho_s,
-            rho_f, c_f,
-            p_0, wave_types, position,
-        ),
-    )
+    sols = [
+        SolutionFactory().king_1934_arf(),
+        SolutionFactory().yosioka_1955_arf(),
+        SolutionFactory().gorkov_1962_arf(),
+    ]
 
-    out.append(
-        yosioka1955.ARF(
-            f, R_0,
-            rho_s, c_s,
-            rho_f, c_f,
-            p_0, wave_types, position,
-        ),
-    )
-
-    out.append(
-        gorkov1962.ARF(
-            f, R_0,
-            rho_s, c_s,
-            rho_f, c_f,
-            p_0, wave_types, position,
-        ),
-    )
-
-    return out
+    return sols
 
 
 class TestARFPlot(BaseTestPlotting):
-
     def setUp(self) -> None:
         super().setUp()
 
@@ -80,10 +49,10 @@ class TestARFPlot(BaseTestPlotting):
         for i in np.arange(6):
             for sol in solutions:
                 tmp = sol
-                tmp.name = f'{tmp.name}_{i}'
+                tmp.name = f"{tmp.name}_{i}"
                 self.plotter.add_solutions(tmp)
 
-        self.plotter.set_abscissa(np.linspace(1e-6, 1e-5), 'R_0')
+        self.plotter.set_abscissa(np.linspace(1e-6, 1e-5), "R_0")
 
         fig, ax = self.plotter.plot_solutions()
 
@@ -99,13 +68,13 @@ class TestARFPlot(BaseTestPlotting):
     def test_repeated_ARF_over_R(self) -> None:
         solutions = create_solutions()
 
-        self.plotter.set_abscissa(np.linspace(1e-6, 1e-5), 'R_0')
+        self.plotter.set_abscissa(np.linspace(1e-6, 1e-5), "R_0")
 
         for sol in solutions:
             self.plotter.add_solutions(sol)
 
-        fig, ax = self.plotter.plot_solutions(ls='--')
-        fig, ax = self.plotter.plot_solutions(linestyle='--')
+        fig, ax = self.plotter.plot_solutions(ls="--")
+        fig, ax = self.plotter.plot_solutions(linestyle="--")
 
         name = inspect.stack()[0][3]  # method name
         self.save_fig(fig, name)
@@ -113,7 +82,7 @@ class TestARFPlot(BaseTestPlotting):
     def test_ARF_over_R(self) -> None:
         solutions = create_solutions()
 
-        self.plotter.set_abscissa(np.linspace(1e-6, 1e-5, num=100), 'R_0')
+        self.plotter.set_abscissa(np.linspace(1e-6, 1e-5, num=100), "R_0")
 
         for sol in solutions:
             self.plotter.add_solutions(sol)
@@ -126,7 +95,7 @@ class TestARFPlot(BaseTestPlotting):
     def test_normARF_over_f(self) -> None:
         solutions = create_solutions()
 
-        self.plotter.set_abscissa(np.linspace(1e4, 5e6, num=100), 'f')
+        self.plotter.set_abscissa(np.linspace(1e4, 5e6, num=100), "f")
 
         for sol in solutions:
             self.plotter.add_solutions(sol)
@@ -141,7 +110,7 @@ class TestARFPlot(BaseTestPlotting):
     def test_normARF_over_f_semilogx(self) -> None:
         solutions = create_solutions()
 
-        self.plotter.set_abscissa(np.linspace(1e4, 5e6, num=100), 'f')
+        self.plotter.set_abscissa(np.linspace(1e4, 5e6, num=100), "f")
 
         for sol in solutions:
             self.plotter.add_solutions(sol)
@@ -157,7 +126,7 @@ class TestARFPlot(BaseTestPlotting):
     def test_normARF_over_f_loglog(self) -> None:
         solutions = create_solutions()
 
-        self.plotter.set_abscissa(np.linspace(1e4, 5e6, num=100), 'f')
+        self.plotter.set_abscissa(np.linspace(1e4, 5e6, num=100), "f")
 
         for sol in solutions:
             self.plotter.add_solutions(sol)
@@ -173,13 +142,13 @@ class TestARFPlot(BaseTestPlotting):
     def test_max_norm_over_f(self):
         solutions = create_solutions()
 
-        self.plotter.set_abscissa(np.linspace(1e4, 5e6, num=100), 'f')
+        self.plotter.set_abscissa(np.linspace(1e4, 5e6, num=100), "f")
 
         for sol in solutions:
             self.plotter.add_solutions(sol)
 
         fig, ax = self.plotter.plot_solutions(
-            normalization='max',
+            normalization="max",
         )
 
         name = inspect.stack()[0][3]  # method name
@@ -187,9 +156,9 @@ class TestARFPlot(BaseTestPlotting):
 
 
 class DummyClass(BaseARF):
-    """Dummy class to test methods
-    """
-    name = 'Dummy'
+    """Dummy class to test methods"""
+
+    name = "Dummy"
     R_0 = 1
 
     def compute_arf(self):
@@ -197,13 +166,12 @@ class DummyClass(BaseARF):
 
 
 class TestARFNormalization(unittest.TestCase):
-
     def setUp(self) -> None:
 
         self.cls = DummyClass()
         self.R_values = np.arange(1, 10)
 
-        self.arf_plot = ARFPlot('R_0', self.R_values)
+        self.arf_plot = ARFPlot("R_0", self.R_values)
         self.arf_plot.add_solutions(self.cls)
 
     def test_display_values(self):
@@ -215,13 +183,13 @@ class TestARFNormalization(unittest.TestCase):
 
     def test_max_norm(self) -> None:
 
-        _, ax = self.arf_plot.plot_solutions(normalization='max')
+        _, ax = self.arf_plot.plot_solutions(normalization="max")
         arf = ax.lines[0].get_ydata()
         self.assertAlmostEqual(max(arf), 1)
         self.assertTrue(np.all(arf <= 1))
 
     def test_other_class_norm(self):
-        norm = 'Dummy'
+        norm = "Dummy"
         _, ax = self.arf_plot.plot_solutions(normalization=norm)
         arf = ax.lines[0].get_ydata()
         self.assertAlmostEqual(max(arf), 1)
@@ -250,20 +218,20 @@ class TestARFNormalization(unittest.TestCase):
 
     def test_wrong_norm(self):
         self.assertRaises(
-            ValueError, self.arf_plot.plot_solutions,
-            normalization='blabla',
+            ValueError,
+            self.arf_plot.plot_solutions,
+            normalization="blabla",
         )
 
 
 class TestMulticore(unittest.TestCase):
-
     def test_multicore(self):
 
         king, _, _ = create_solutions()
         king_copy = king.copy()
-        king_copy.name = 'King Copy'
+        king_copy.name = "King Copy"
 
-        plot = ARFPlot('R_0', np.linspace(1e-6, 10e6))
+        plot = ARFPlot("R_0", np.linspace(1e-6, 10e6))
         plot.add_solutions(king)
         plot.add_solutions(king_copy, multicore=True)
 
@@ -275,5 +243,5 @@ class TestMulticore(unittest.TestCase):
         np.testing.assert_array_equal(arf_king, arf_king_copy)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
