@@ -1,44 +1,27 @@
 import unittest
 
-from osaft import yosioka1955
 from osaft.core.functions import pi
 from osaft.plotting.datacontainers.scattering_datacontainer import (
     FluidScatteringData,
 )
-from osaft.solutions import doinikov1994rigid
-from osaft.tests.basetest import BaseTest
+from osaft.tests.solution_factory import SolutionFactory
 
 
-class TestBaseScatteringDatacontainer(BaseTest):
-
+class TestBaseScatteringDatacontainer(unittest.TestCase):
     def setUp(self) -> None:
-
         super().setUp()
 
-        self.sol = yosioka1955.ScatteringField(
-            self.f, self.R_0,
-            self.rho_s, self.c_s,
-            self.rho_f, self.c_f,
-            self.p_0,
-            self.wave_type,
-            self.position,
-        )
+        self.sol = SolutionFactory().yosioka_1955_scattering()
 
         self.cls = FluidScatteringData(
-            self.sol, 5 * self.sol.R_0,
+            self.sol,
+            5 * self.sol.R_0,
         )
 
     def test_setters_and_getters(self):
         # Change solution
-        sol_2 = doinikov1994rigid.ScatteringField(
-            self.f, self.R_0,
-            self.rho_s,
-            self.rho_f, self.c_f,
-            self.eta_f, self.zeta_f,
-            self.p_0,
-            self.wave_type,
-            self.position,
-        )
+        sol_2 = SolutionFactory().doinikov_1994_rigid_scattering()
+
         self.cls.sol = sol_2
 
         # Change r_min
@@ -57,10 +40,14 @@ class TestBaseScatteringDatacontainer(BaseTest):
         self.cls.theta_max = pi / 2
         self.assertEqual(self.cls.theta_max, pi / 2)
 
+        # Change n_quiver_points
+        self.cls.n_quiver_points = 42
+        self.assertEqual(self.cls.n_quiver_points, 42)
+
     def test_change_resolution(self):
         self.cls.resolution = 200
-        self.assertEqual(self.cls.grid.r_res, 200)
+        self.assertEqual(self.cls.grid.res_r, 200)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
