@@ -2,28 +2,19 @@ import unittest
 
 import numpy as np
 
-from osaft import yosioka1955
 from osaft.core.functions import exp
 from osaft.plotting.datacontainers.scattering_datacontainer import (
     ParticleScatteringData,
 )
-from osaft.tests.basetest import BaseTest
+from osaft.tests.solution_factory import SolutionFactory
 
 
-class TestParticleScatteringDatacontainer(BaseTest):
-
+class TestParticleScatteringDatacontainer(unittest.TestCase):
     def setUp(self) -> None:
 
         super().setUp()
 
-        self.sol = yosioka1955.ScatteringField(
-            self.f, self.R_0,
-            self.rho_s, self.c_s,
-            self.rho_f, self.c_f,
-            self.p_0,
-            self.wave_type,
-            self.position,
-        )
+        self.sol = SolutionFactory().yosioka_1955_scattering()
 
         self.cls = ParticleScatteringData(
             self.sol,
@@ -105,5 +96,5 @@ class TestParticleScatteringDatacontainer(BaseTest):
         np.testing.assert_allclose(v, v_test)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
